<?php
/**
 * The admin-specific functionality of the plugin.
 *
 * @link       https://cedcommerce.com
 * @since      1.0.0
 *
 * @package    Shopify_Connector_For_Woocommerce
 * @subpackage Shopify_Connector_For_Woocommerce/admin
 */

/**
 * The admin-specific functionality of the plugin.
 *
 * Defines the plugin name, version, and two examples hooks for how to
 * enqueue the admin-specific stylesheet and JavaScript.
 *
 * @package    Shopify_Connector_For_Woocommerce
 * @subpackage Shopify_Connector_For_Woocommerce/admin
 */
class Shopify_Connector_For_Woocommerce_Admin {

	/**
	 * The ID of this plugin.
	 *
	 * @since    1.0.0
	 * @var      string    $plugin_name    The ID of this plugin.
	 */
	private $plugin_name;

	/**
	 * The version of this plugin.
	 *
	 * @since    1.0.0
	 * @var      string    $version    The current version of this plugin.
	 */
	private $version;

	/**
	 * Initialize the class and set its properties.
	 *
	 * @since    1.0.0
	 * @param      string $plugin_name       The name of this plugin.
	 * @param      string $version    The version of this plugin.
	 */
	public function __construct( $plugin_name, $version ) {
		$this->plugin_name = $plugin_name;
		$this->version     = $version;
		add_action( 'init', array( $this, 'plugins_loaded' ) );
		add_action( 'wp_ajax_ced_scw_search_cate', array( $this, 'ced_scw_search_cate' ) );
		add_action( 'wp_ajax_ced_update_plan', array( $this, 'ced_update_plan_state' ) );
		add_action( 'wp_ajax_nopriv_ced_update_plan', array( $this, 'ced_update_plan_state' ) );

		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/shopify/class-ced-shopify-product.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/shopify/class-ced-shopify-customers.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/shopify/class-ced-shopify-orders.php';
	}

	/**
	 * Ced_update_plan_state.
	 *
	 * @since    1.0.0
	 */
	public function ced_update_plan_state() {
		$post_body = json_decode( file_get_contents( 'php://input' ), 1 );
		if ( isset( $post_body['subscription_status'] ) ) {
			$data                                 = get_option( 'ced_saas_contract_details', array() );
			$data['shopify']['plan_status']       = $post_body['subscription_status'];
			$data['shopify']['next_payment_date'] = $post_body['next_payment_date'];
			$data['shopify']['end_date']          = $post_body['end_date'];
			update_option( 'ced_saas_contract_details', $data );
		}
	}

	/**
	 * Plugins_loaded.
	 *
	 * @since    1.0.0
	 */
	public function plugins_loaded() {
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-shopify-process-for-import-background-images.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-wp-background-process.php';
		require_once plugin_dir_path( dirname( __FILE__ ) ) . 'includes/class-wp-async-request.php';
		global $process;
		$process = new Shopify_Process_For_Import_Background_Images();
	}

	/**
	 * Register the stylesheets for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_styles() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Shopify_Connector_For_Woocommerce_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Shopify_Connector_For_Woocommerce_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		if ( isset( $_GET['page'] ) && 'ced_plans' === $_GET['page'] ) {
			wp_enqueue_style( 'handler_bootstrap', plugin_dir_url( __FILE__ ) . 'css/bootstrap.min.css', array(), time(), 'all' );
		}
		wp_enqueue_style( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'css/shopify-connector-for-woocommerce-admin.css', array(), time(), 'all' );
		wp_enqueue_style( 'handler_select_2_css', plugin_dir_url( __FILE__ ) . 'css/select2.min.css', array(), time(), 'all' );

	}

	/**
	 * Register the JavaScript for the admin area.
	 *
	 * @since    1.0.0
	 */
	public function enqueue_scripts() {

		/**
		 * This function is provided for demonstration purposes only.
		 *
		 * An instance of this class should be passed to the run() function
		 * defined in Shopify_Connector_For_Woocommerce_Loader as all of the hooks are defined
		 * in that particular class.
		 *
		 * The Shopify_Connector_For_Woocommerce_Loader will then create the relationship
		 * between the defined hooks and the functions defined in this
		 * class.
		 */
		if ( ( ( isset( $_GET['section'] ) && 'setting-page' == $_GET['section'] ) || ( isset( $_GET['section'] ) && 'progress-page' == $_GET['section'] ) ) && ( isset( $_GET['platform'] ) && 'shopify' == $_GET['platform'] ) ) {
			wp_enqueue_script( 'shopify-js', plugin_dir_url( dirname( __FILE__ ) ) . 'includes/shopify/shopify-importer.js', array( 'jquery' ), time(), false );
		}
		wp_enqueue_script( $this->plugin_name, plugin_dir_url( __FILE__ ) . 'js/shopify-connector-for-woocommerce-admin.js', array( 'jquery' ), time(), false );
		wp_enqueue_script( 'handler_select_2_js', plugin_dir_url( __FILE__ ) . 'js/select2.min.js', array(), time(), 'all' );
		wp_enqueue_script( 'selectWoo' );

		$ajax_nonce            = wp_create_nonce( 'ced-shopify-ajax-seurity-string' );
		$get_shopify_store_url = sanitize_text_field( wp_unslash( isset( $_GET['shopify_store'] ) ? $_GET['shopify_store'] : '' ) );

		$localize_array = array(
			'ajax_url'          => admin_url( 'admin-ajax.php' ),
			'ajax_nonce'        => $ajax_nonce,
			'site_url'          => admin_url() . 'admin.php?page=ced_shopify&section=configuration',
			'shopify_store_URL' => $get_shopify_store_url,
		);
		wp_localize_script( $this->plugin_name, 'Ced_Shopify_connector_action_handler', $localize_array );
	}

	/**
	 * Ced_scw_add_menus.
	 *
	 * @return void
	 */
	public function ced_scw_add_menus() {
		global $submenu;
		if ( empty( $GLOBALS['admin_page_hooks']['cedcommerce-integrations'] ) ) {
			add_menu_page( __( 'Marketplaces', 'shopify-connector-for-woocommerce' ), __( 'Marketplaces', 'shopify-connector-for-woocommerce' ), 'manage_woocommerce', 'cedcommerce-integrations', array( $this, 'ced_scw_marketplace_listing_page' ), 'dashicons-store', 12 );
			$menus = apply_filters( 'ced_add_marketplace_menus_array', array() );
			if ( is_array( $menus ) && ! empty( $menus ) ) {
				foreach ( $menus as $key => $value ) {
					add_submenu_page( 'cedcommerce-integrations', $value['name'], $value['name'], 'manage_woocommerce', $value['menu_link'], array( $value['instance'], $value['function'] ) );
				}
				add_submenu_page( 'cedcommerce-integrations', 'Plans', 'Plans', 'manage_woocommerce', 'ced_plans', array( $this, 'ced_plan_callback' ) );
			}
		}
	}

	/**
	 * Ced_plan_callback.
	 *
	 * @return void
	 */
	public function ced_plan_callback() {
		if ( file_exists( CED_SCW_PATH . 'admin/partials/ced-scw-pricing-plan.php' ) ) {
			require_once CED_SCW_PATH . 'admin/partials/ced-scw-pricing-plan.php';
		}
	}

	/**
	 * Ced_scw_add_saas_marketplace_to_array
	 *
	 * @param mixed $menus Menus.
	 * @return $menus Menus.
	 */
	public function ced_scw_add_saas_marketplace_to_array( $menus = array() ) {
		$menus['shopify'] = 'Shopify';
		return $menus;
	}

	/**
	 * Ced_scw_marketplace_listing_page
	 *
	 * @return void
	 */
	public function ced_scw_marketplace_listing_page() {
		$active_marketplaces = apply_filters( 'ced_add_marketplace_menus_array', array() );
		if ( is_array( $active_marketplaces ) && ! empty( $active_marketplaces ) ) {
			require CED_SCW_PATH . 'admin/partials/marketplaces.php';
		}
	}

	/**
	 * Ced_scw_add_marketplace_menus_to_array.
	 *
	 * @param  mixed $menus Menus.
	 * @return $menus
	 */
	public function ced_scw_add_marketplace_menus_to_array( $menus = array() ) {
		$menus[] = array(
			'name'            => 'Shopify',
			'slug'            => 'shopify-connector-for-woocommerce',
			'menu_link'       => 'ced_shopify',
			'instance'        => $this,
			'function'        => 'ced_scw_accounts_page',
			'card_image_link' => CED_SCW_URL . 'admin/images/shopify_logo.jpg',
		);
		return $menus;
	}

	/**
	 * Ced_scw_accounts_page
	 *
	 * @return void
	 */
	public function ced_scw_accounts_page() {
		if ( ! empty( $_GET['success'] ) && ! empty( $_GET['contract_id'] ) ) {
			$data              = get_option( 'ced_saas_contract_details', array() );
			$contract_id       = isset( $_GET['contract_id'] ) ? sanitize_text_field( wp_unslash( $_GET['contract_id'] ) ) : '';
			$plan_name         = isset( $_GET['plan_name'] ) ? sanitize_text_field( wp_unslash( $_GET['plan_name'] ) ) : '';
			$billing_period    = isset( $_GET['billing_period'] ) ? sanitize_text_field( wp_unslash( $_GET['billing_period'] ) ) : '';
			$plan_status       = isset( $_GET['status'] ) ? sanitize_text_field( wp_unslash( $_GET['status'] ) ) : '';
			$next_payment_date = isset( $_GET['next_payment_date'] ) ? sanitize_text_field( wp_unslash( $_GET['next_payment_date'] ) ) : '';
			$end_date          = isset( $_GET['end_date'] ) ? sanitize_text_field( wp_unslash( $_GET['end_date'] ) ) : '';

			$data['shopify'] = array(
				'contract_id'       => $contract_id,
				'plan_name'         => $plan_name,
				'billing_period'    => $billing_period,
				'plan_status'       => $plan_status,
				'next_payment_date' => $next_payment_date,
				'end_date'          => $end_date,
			);
			update_option( 'ced_scw_pricing_selected', 'true' );
			update_option( 'ced_saas_contract_details', $data );
		}
		$pricing_subscribed      = get_option( 'ced_scw_pricing_selected', false );
		$pricing_subscribed_data = get_option( 'ced_saas_contract_details', array() );
		if ( ! empty( $pricing_subscribed_data['shopify']['plan_status'] ) ) {
			$pricing_status = $pricing_subscribed_data['shopify']['plan_status'];
		} else {
			$pricing_status = '';
		}
		if ( ! empty( $pricing_subscribed_data['shopify']['end_date'] ) ) {
			$end_date = strtotime( $pricing_subscribed_data['shopify']['end_date'] );
		} else {
			$end_date = '';
		}
		$current_date = strtotime( gmdate( 'Y-m-d h:i:s' ) );
		if ( ! empty( $end_date ) && $current_date >= $end_date ) {
			$active_plan = 'no';
		} else {
			$active_plan = 'yes';
		}
		if ( 'true' === $pricing_subscribed && ( 'canceled' !== $pricing_status || 'no' !== $active_plan ) ) {
			$ced_section  = sanitize_text_field( wp_unslash( isset( $_GET['section'] ) ? $_GET['section'] : '' ) );
			$ced_platform = sanitize_text_field( wp_unslash( isset( $_GET['platform'] ) ? $_GET['platform'] : '' ) );

			if ( ! empty( $ced_section ) && ! empty( $ced_platform ) ) {
				if ( 'setting-page' == $ced_section && 'shopify' == $ced_platform ) {
					$file = CED_SCW_PATH . 'includes/' . sanitize_text_field( 'shopify' ) . '/' . sanitize_text_field( 'setting-page' ) . '.php';
				} elseif ( 'progress-page' == $ced_section && 'shopify' == $ced_platform ) {
					$file = CED_SCW_PATH . 'includes/' . sanitize_text_field( 'shopify' ) . '/' . sanitize_text_field( 'progress-page' ) . '.php';
				}

				if ( file_exists( $file ) ) {
					include_once $file;
				}
			} else {
				if ( file_exists( CED_SCW_PATH . 'admin/partials/ced-scw-main.php' ) ) {
					require_once CED_SCW_PATH . 'admin/partials/ced-scw-main.php';
				}
			}
		} else {
			$url = admin_url( 'admin.php?page=ced_plans&product_plan=shopify' );
			if ( ! headers_sent() ) {
				header( 'Location: ' . $url );
				exit;
			} else {
				echo '<script type="text/javascript">';
				echo 'window.location.href="' . esc_attr( $url ) . '";';
				echo '</script>';
				echo '<noscript>';
				echo '<meta http-equiv="refresh" content="0;url=' . esc_attr( $url ) . '" />';
				echo '</noscript>';
				exit;
			}
		}
	}
	/**
	 * Ced_scw_fetch_shopify_collection_recursive
	 *
	 * @return void
	 */
	public function ced_scw_fetch_shopify_collection_recursive() {

		$check_ajax = check_ajax_referer( 'ced-shopify-ajax-seurity-string', 'nonce' );
		if ( $check_ajax ) {

			$collection_name = get_option( 'ced_scw_save_collections_title_list', array() );
			$sanitized       = filter_input_array( INPUT_POST );
			require_once CED_SCW_PATH . 'includes/shopify/class-ced-shopify-server-response.php';
			$ced_shopify_server_obj = Ced_Shopify_Server_Response::get_instance();

			$render_settings_data = get_option( 'ced_shopify_settings_data', false );

			if ( isset( $render_settings_data['store_address'] ) && isset( $render_settings_data['access_token'] ) ) {
				$ced_store_address = $render_settings_data['store_address'];
				$ced_access_token  = $render_settings_data['access_token'];
			}

			$shopify_collection_type     = isset( $sanitized['shopify_collection_type'] ) ? $sanitized['shopify_collection_type'] : '';
			$shopify_collection_since_id = isset( $sanitized['shopify_collection_since_id'] ) ? (int) $sanitized['shopify_collection_since_id'] : 0;
			$params                      = array();
			$params['domain']            = home_url();
			$params['shop_url']          = ! empty( $ced_store_address ) ? $ced_store_address : '';
			$params['access_token']      = ! empty( $ced_access_token ) ? $ced_access_token : '';
			$params['channel']           = 'shopify';
			if ( 'custom_collections' === $shopify_collection_type ) {
				$params['functionType'] = 'getCollectionsFromStore';
				$params['since_id']     = $shopify_collection_since_id;
				$custom_collections     = $ced_shopify_server_obj->get_server_response_data( $params );
				$collection_array       = isset( $custom_collections['custom_collections'] ) ? $custom_collections['custom_collections'] : '';

				if ( ! empty( $collection_array ) ) {
					foreach ( $collection_array as $value ) {
						$collection_name[ $ced_store_address ][ $value['id'] ] = $value['title'];
					}

					asort( $collection_name );
					update_option( 'ced_scw_save_collections_title_list', $collection_name );
					$shopify_collection_since_id = $value['id'];
					$execution                   = 'continue';
					$shopify_collection_type     = 'custom_collections';
				} else {
					$shopify_collection_since_id = 0;
					$execution                   = '';
					$shopify_collection_type     = 'custom_collections';
				}
			} else {
				$params['functionType']     = 'getSmartCollectionsFromStore';
				$params['since_id']         = $shopify_collection_since_id;
				$smart_collections          = $ced_shopify_server_obj->get_server_response_data( $params );
				$smart_collections_array    = isset( $smart_collections['smart_collections'] ) ? $smart_collections['smart_collections'] : '';
				$collection_save_title_list = get_option( 'ced_scw_save_collections_title_list', array() );

				if ( ! empty( $smart_collections_array ) ) {
					foreach ( $smart_collections_array as $value ) {
						$collection_name[ $ced_store_address ][ $value['id'] ] = $value['title'];
					}

					asort( $collection_name );
					$collection_name = array_merge( $collection_name, $collection_save_title_list );
					update_option( 'ced_scw_save_collections_title_list', $collection_name );

					$execution                   = 'continue';
					$shopify_collection_type     = 'smart_collections';
					$shopify_collection_since_id = $value['id'];
				} else {
					$shopify_collection_since_id = 0;
					$shopify_collection_type     = '';
					$execution                   = 'smart_collections';
				}
			}

			echo json_encode(
				array(
					'execution'                  => $execution,
					'shopify_admin_store_url'    => $ced_store_address,
					'shopify_collection_type'    => $shopify_collection_type,
					'shopify_collection_sinceID' => (int) $shopify_collection_since_id,
				)
			);
			die;
		}
	}
	/**
	 * Ced_scw_fetch_steps_shopify
	 *
	 * @return void
	 */
	public function ced_scw_fetch_steps_shopify() {
		$check_ajax = check_ajax_referer( 'ced-shopify-ajax-seurity-string', 'nonce' );
		if ( $check_ajax ) {
			$opr_type      = isset( $_POST['opr_type'] ) ? sanitize_text_field( wp_unslash( $_POST['opr_type'] ) ) : '';
			$settings_data = get_option( 'ced_shopify_settings_data', true );

			$product_import  = '';
			$customer_import = '';
			$order_import    = '';

			if ( isset( $settings_data ) && ! empty( $settings_data ) ) {

				if ( 'product' == $opr_type ) {
					if ( isset( $settings_data['enable_product_import'] ) && 'on' === $settings_data['enable_product_import'] ) {
						echo json_encode(
							array(
								'status' => 'yes',
							)
						);
						die;
					} else {
						echo json_encode(
							array(
								'status' => 'no',
							)
						);
						die;
					}
				} elseif ( 'customer' == $opr_type ) {
					if ( isset( $settings_data['enable_customer_import'] ) && 'on' === $settings_data['enable_customer_import'] ) {
						echo json_encode(
							array(
								'status' => 'yes',
							)
						);
						die;
					} else {
						echo json_encode(
							array(
								'status' => 'no',
							)
						);
						die;
					}
				} elseif ( 'order' == $opr_type ) {
					if ( isset( $settings_data['enable_order_import'] ) && 'on' == $settings_data['enable_order_import'] ) {
						echo json_encode(
							array(
								'status' => 'yes',
							)
						);
						die;
					} else {
						echo json_encode(
							array(
								'status' => 'no',
							)
						);
						die;
					}
				}
			}
			wp_die();
		}
	}

	/**
	 * Ced_scw_fetch_log_file_path_shopify
	 *
	 * @return void
	 */
	public function ced_scw_fetch_log_file_path_shopify() {
		$check_ajax = check_ajax_referer( 'ced-shopify-ajax-seurity-string', 'nonce' );
		if ( $check_ajax ) {
			$opr_type = isset( $_POST['opr_type'] ) ? sanitize_text_field( wp_unslash( $_POST['opr_type'] ) ) : '';
			if ( 'product' === $opr_type ) {
				$product_log_file_name = 'ced-shopify_importer-log-file-product-' . time() . '.txt';
				$product_log_path      = wp_upload_dir()['basedir'] . '/cedcommerce-shopify-importer-logs/shopify-logs/' . $product_log_file_name;
				$product_log_url       = wp_upload_dir()['baseurl'] . '/cedcommerce-shopify-importer-logs/shopify-logs/' . $product_log_file_name;
				$file_open             = fopen( $product_log_path, 'a' );
				fclose( $file_open );
				echo json_encode(
					array(
						'product_log_url'  => $product_log_url,
						'product_log_path' => $product_log_path,
					)
				);
				die;
			} elseif ( 'customer' === $opr_type ) {
				$customer_log_file_name = 'ced-shopify_importer-log-file-customer-' . time() . '.txt';
				$customer_log_path      = wp_upload_dir()['basedir'] . '/cedcommerce-shopify-importer-logs/shopify-logs/' . $customer_log_file_name;
				$customer_log_url       = wp_upload_dir()['baseurl'] . '/cedcommerce-shopify-importer-logs/shopify-logs/' . $customer_log_file_name;
				$file_open              = fopen( $customer_log_path, 'a' );
				fclose( $file_open );
				echo json_encode(
					array(
						'customer_log_url'  => $customer_log_url,
						'customer_log_path' => $customer_log_path,
					)
				);
				die;
			} elseif ( 'order' == $opr_type ) {
				$order_log_file_name = 'ced-shopify_importer-log-file-order-' . time() . '.txt';
				$order_log_path      = wp_upload_dir()['basedir'] . '/cedcommerce-shopify-importer-logs/shopify-logs/' . $order_log_file_name;
				$order_log_url       = wp_upload_dir()['baseurl'] . '/cedcommerce-shopify-importer-logs/shopify-logs/' . $order_log_file_name;
				$file_open           = fopen( $order_log_path, 'a' );
				fclose( $file_open );
				echo json_encode(
					array(
						'order_log_url'  => $order_log_url,
						'order_log_path' => $order_log_path,
					)
				);
				die;
			}
			wp_die();
		}
	}

	/**
	 * Ced_scw_fetch_product_data_shopify
	 *
	 * @return void
	 */
	public function ced_scw_fetch_product_data_shopify() {
		$check_ajax = check_ajax_referer( 'ced-shopify-ajax-seurity-string', 'nonce' );
		if ( $check_ajax ) {
			$render_settings_data = get_option( 'ced_shopify_settings_data', true );
			if ( isset( $render_settings_data['product_chunk_size'] ) && ! empty( $render_settings_data['product_chunk_size'] ) ) {
				$chunk = $render_settings_data['product_chunk_size'];
			} else {
				$chunk = 5;
			}
			$total_product           = isset( $_POST['total_product'] ) ? sanitize_text_field( wp_unslash( $_POST['total_product'] ) ) : '';
			$left_product            = isset( $_POST['left_product'] ) ? sanitize_text_field( wp_unslash( $_POST['left_product'] ) ) : '';
			$processed_product       = isset( $_POST['processed_product'] ) ? sanitize_text_field( wp_unslash( $_POST['processed_product'] ) ) : '';
			$product_log_path        = isset( $_POST['product_path'] ) ? sanitize_text_field( wp_unslash( $_POST['product_path'] ) ) : '';
			$limit                   = $chunk;
			$page                    = isset( $_POST['page'] ) ? sanitize_text_field( wp_unslash( $_POST['page'] ) ) : '';
			$ced_shopify_product_obj = Ced_Shopify_Product::get_instance();
			$ced_shopify_product_obj->ced_shopify_prepare_product_data_to_import( $total_product, $left_product, $limit, $page, $product_log_path );
			wp_die();
		}
	}

	/**
	 * Ced_shopify_prepare_product_ids_to_import
	 *
	 * @return void
	 */
	public function ced_shopify_prepare_product_ids_to_import() {
		$ced_shopify_product_obj = Ced_Shopify_Product::get_instance();
		$ced_shopify_product_obj->ced_shopify_prepare_product_ids_to_import();
		wp_die();
	}

	/**
	 * Ced_shopify_fetch_customers_data
	 *
	 * @return void
	 */
	public function ced_shopify_fetch_customers_data() {
		$check_ajax = check_ajax_referer( 'ced-shopify-ajax-seurity-string', 'nonce' );
		if ( $check_ajax ) {
			$render_settings_data = get_option( 'ced_shopify_settings_data', true );
			if ( isset( $render_settings_data['customer_chunk_size'] ) && ! empty( $render_settings_data['customer_chunk_size'] ) ) {
				$chunk = $render_settings_data['customer_chunk_size'];
			} else {
				$chunk = 5;
			}
			$total_customer            = isset( $_POST['total_customer'] ) ? sanitize_text_field( wp_unslash( $_POST['total_customer'] ) ) : '';
			$left_customer             = isset( $_POST['left_customer'] ) ? sanitize_text_field( wp_unslash( $_POST['left_customer'] ) ) : '';
			$processed_customer        = isset( $_POST['processed_customer'] ) ? sanitize_text_field( wp_unslash( $_POST['processed_customer'] ) ) : '';
			$customer_log_path         = isset( $_POST['customer_path'] ) ? sanitize_text_field( wp_unslash( $_POST['customer_path'] ) ) : '';
			$limit                     = $chunk;
			$since_id                  = isset( $_POST['since_id'] ) ? sanitize_text_field( wp_unslash( $_POST['since_id'] ) ) : '';
			$ced_shopify_customers_obj = Ced_Shopify_Customers::get_instance();
			$ced_shopify_customers_obj->ced_shopify_prepare_customer_data_to_import( $total_customer, $left_customer, $limit, $since_id, $customer_log_path );

			wp_die();
		}
	}
	/**
	 * Ced_shopify_fetch_orders
	 *
	 * @return void
	 */
	public function ced_shopify_fetch_orders() {
		$check_ajax = check_ajax_referer( 'ced-shopify-ajax-seurity-string', 'nonce' );
		if ( $check_ajax ) {
			$render_settings_data = get_option( 'ced_shopify_settings_data', false );
			if ( isset( $render_settings_data['order_chunk_size'] ) && ! empty( $render_settings_data['order_chunk_size'] ) ) {
				$chunk = $render_settings_data['order_chunk_size'];
			} else {
				$chunk = 5;
			}
			$total_order               = isset( $_POST['total_order'] ) ? sanitize_text_field( wp_unslash( $_POST['total_order'] ) ) : '';
			$left_order                = isset( $_POST['left_order'] ) ? sanitize_text_field( wp_unslash( $_POST['left_order'] ) ) : '';
			$processed_order           = isset( $_POST['processed_order'] ) ? sanitize_text_field( wp_unslash( $_POST['processed_order'] ) ) : '';
			$order_path                = isset( $_POST['order_path'] ) ? sanitize_text_field( wp_unslash( $_POST['order_path'] ) ) : '';
			$limit                     = $chunk;
			$since_id                  = isset( $_POST['since_id'] ) ? sanitize_text_field( wp_unslash( $_POST['since_id'] ) ) : '';
			$ced_shopify_get_all_order = Ced_Shopify_Orders::get_instance();
			$ced_shopify_get_all_order->ced_shopify_create_orders( $total_order, $left_order, $limit, $since_id, $order_path );
			wp_die();
		}
	}
	/**
	 * Ced_scw_pricing_plan_selection
	 *
	 * @return void
	 */
	public function ced_scw_pricing_plan_selection() {
		$check_ajax = check_ajax_referer( 'ced-shopify-ajax-seurity-string', 'nonce' );
		if ( $check_ajax ) {
			$params                  = array();
			$pricing_subscribed_data = get_option( 'ced_saas_contract_details', array() );
			if ( ! empty( $pricing_subscribed_data['shopify']['plan_status'] ) ) {
				$pricing_status = $pricing_subscribed_data['shopify']['plan_status'];
			} else {
				$pricing_status = '';
			}
			$params['plan_type'] = ! empty( $_POST['plan_type'] ) ? sanitize_text_field( wp_unslash( $_POST['plan_type'] ) ) : '';
			$params['plan_cost'] = ! empty( $_POST['plan_cost'] ) ? sanitize_text_field( wp_unslash( $_POST['plan_cost'] ) ) : '';
			if ( 'canceled' !== $pricing_status ) {
				$params['contract_id'] = ! empty( $_POST['contract_id'] ) ? sanitize_text_field( wp_unslash( $_POST['contract_id'] ) ) : '';
			}
			$params['plan_period']  = ! empty( $_POST['plan_period'] ) ? sanitize_text_field( wp_unslash( $_POST['plan_period'] ) ) : '';
			$params['channel']      = 'shopify';
			$params['redirect_url'] = home_url();
			$build_query            = http_build_query( $params );
			$url                    = 'https://woodemo.cedcommerce.com/wooapi/ced-process-payment.php?' . $build_query;
			$connection             = curl_init();
			curl_setopt( $connection, CURLOPT_URL, $url );
			curl_setopt( $connection, CURLOPT_SSL_VERIFYPEER, 0 );
			curl_setopt( $connection, CURLOPT_POST, 0 );
			curl_setopt( $connection, CURLOPT_SSL_VERIFYHOST, 0 );
			curl_setopt( $connection, CURLOPT_RETURNTRANSFER, 1 );
			$response = curl_exec( $connection );
			$response = json_decode( $response, 1 );
			curl_close( $connection );

			echo json_encode( $response );
			wp_die();
		}
	}
	/**
	 * Ced_scw_pricing_plan_cancellation
	 *
	 * @return void
	 */
	public function ced_scw_pricing_plan_cancellation() {
		$check_ajax = check_ajax_referer( 'ced-shopify-ajax-seurity-string', 'nonce' );
		if ( $check_ajax ) {
			$params                 = array();
			$params['contract_id']  = ! empty( $_POST['contract_id'] ) ? sanitize_text_field( wp_unslash( $_POST['contract_id'] ) ) : '';
			$params['channel']      = 'shopify';
			$params['is_cancel']    = 'yes';
			$params['redirect_url'] = home_url();
			$build_query            = http_build_query( $params );
			$url                    = 'https://woodemo.cedcommerce.com/wooapi/ced-process-payment.php?' . $build_query;
			$connection             = curl_init();
			curl_setopt( $connection, CURLOPT_URL, $url );
			curl_setopt( $connection, CURLOPT_SSL_VERIFYPEER, 0 );
			curl_setopt( $connection, CURLOPT_POST, 0 );
			curl_setopt( $connection, CURLOPT_SSL_VERIFYHOST, 0 );
			curl_setopt( $connection, CURLOPT_RETURNTRANSFER, 1 );
			$response = curl_exec( $connection );
			curl_close( $connection );
			$response_data = json_decode( $response, true );
			if ( ! empty( $response_data ) && '200' == $response_data['status'] ) {
				$data                           = get_option( 'ced_saas_contract_details', array() );
				$data['shopify']['plan_status'] = 'canceled';
				update_option( 'ced_saas_contract_details', $data );
			}
			print_r( $response );
			wp_die();
		}
	}
	/**
	 * Ced_scw_validate_token
	 *
	 * @return void
	 */
	public function ced_scw_validate_token() {
		$check_ajax = check_ajax_referer( 'ced-shopify-ajax-seurity-string', 'nonce' );
		if ( $check_ajax ) {
			require_once CED_SCW_PATH . 'includes/shopify/class-ced-shopify-server-response.php';
			$ced_shopify_server_obj = Ced_Shopify_Server_Response::get_instance();
			$shop_url               = isset( $_POST['shop_url'] ) ? sanitize_text_field( wp_unslash( $_POST['shop_url'] ) ) : '';
			$access_token           = isset( $_POST['access_token'] ) ? sanitize_text_field( wp_unslash( $_POST['access_token'] ) ) : '';
			if ( ! empty( $shop_url ) && ! empty( $access_token ) ) {
				$admin_store_url           = rtrim( $shopify_url, '/' ) . '/';
				$params                    = array();
				$params['domain']          = home_url();
				$params['functionType']    = 'ced_scw_fetch_access_scope';
				$params['access_token']    = $access_token;
				$params['shop_url']        = $shop_url;
				$params['since_id']        = '';
				$params['channel']         = 'shopify';
				$params['admin_store_url'] = $shop_url;
				$response                  = $ced_shopify_server_obj->get_server_response_data( $params );

				if ( isset( $response['access_scopes'] ) ) {
					update_option( 'ced_shopify_api_status', 'valid' );
					$settings_data                  = get_option( 'ced_shopify_settings_data', array() );
					$settings_data['store_address'] = $shop_url;
					$settings_data['access_token']  = $access_token;
					update_option( 'ced_shopify_settings_data', $settings_data );
					echo wp_json_encode(
						array(
							'code'    => '200',
							'message' => esc_html( __( 'Store URL and Access Token are valid.', 'shopify-connector-for-woocommerce' ) ),
						)
					);
					wp_die();
				} elseif ( isset( $response['errors'] ) || isset( $response['status'] ) ) {
					$error_msg = isset( $response['errors'] ) ? $response['errors'] : $response['message'];
					update_option( 'ced_shopify_api_status', 'invalid' );
					echo wp_json_encode(
						array(
							'code'    => '400',
							'message' => esc_html( __( $error_msg, 'shopify-connector-for-woocommerce' ) ),
						)
					);
					wp_die();
				} else {
					update_option( 'ced_shopify_api_status', 'invalid' );
					echo wp_json_encode(
						array(
							'code'    => '400',
							'message' => esc_html( __( 'Invalid Store URL or Token', 'shopify-connector-for-woocommerce' ) ),
						)
					);
					wp_die();
				}
			} else {
				echo wp_json_encode(
					array(
						'code'    => '400',
						'message' => 'Shop URL/ Access Token could not be empty',
					)
				);
				wp_die();
			}
		}
	}
	/**
	 * Ced_scw_fetch_shopify_stored_collection
	 *
	 * @return void
	 */
	public function ced_scw_fetch_shopify_stored_collection() {
		$check_ajax = check_ajax_referer( 'ced-shopify-ajax-seurity-string', 'nonce' );
		if ( $check_ajax ) {
			$render_settings_data        = get_option( 'ced_shopify_settings_data', false );
			$collection_data             = isset( $render_settings_data['collection_data'] ) ? $render_settings_data['collection_data'] : array();
			$collection_fetch_data_array = get_option( 'ced_scw_save_collections_title_list', true );
			$collection_data_final       = isset( $collection_fetch_data_array[ $render_settings_data['store_address'] ] ) ? $collection_fetch_data_array[ $render_settings_data['store_address'] ] : array();
			$options                     = '';
			if ( ! empty( $collection_data_final ) ) {
				foreach ( $collection_data_final as $key => $value ) {
					if ( is_array( $collection_data ) && ! empty( is_array( $collection_data ) ) ) {
						if ( in_array( $key, $collection_data ) ) {
							$selected = 'selected';
							$options .= '<option value ="' . $key . '" ' . $selected . '>' . $value . ' </option>';
						} else {
							$options .= '<option value ="' . $key . '" >' . $value . ' </option>';
						}
					} else {
						$options .= '<option value ="' . $key . '" >' . $value . ' </option>';
					}
				}
			}
			print_r( $options );
		}
		wp_die();
	}

	/**
	 * Ced_scw_fetch_locations
	 *
	 * @return void
	 */
	public function ced_scw_fetch_locations() {
		$check_ajax = check_ajax_referer( 'ced-shopify-ajax-seurity-string', 'nonce' );
		if ( $check_ajax ) {
			require_once CED_SCW_PATH . 'includes/shopify/class-ced-shopify-server-response.php';
			$ced_shopify_server_obj = Ced_Shopify_Server_Response::get_instance();
			$render_settings_data   = get_option( 'ced_shopify_settings_data', false );
			if ( isset( $render_settings_data['store_address'] ) && isset( $render_settings_data['access_token'] ) ) {
				$ced_store_address = $render_settings_data['store_address'];
				$ced_access_token  = $render_settings_data['access_token'];
			}

			$params                 = array();
			$params['domain']       = home_url();
			$params['shop_url']     = ! empty( $ced_store_address ) ? $ced_store_address : '';
			$params['access_token'] = ! empty( $ced_access_token ) ? $ced_access_token : '';
			$params['channel']      = 'shopify';
			$params['functionType'] = 'getLocationFromStore';
			$store_locations        = $ced_shopify_server_obj->get_server_response_data( $params );

			if ( is_array( $store_locations ) && array_key_exists( 'locations', $store_locations ) ) {
				update_option( 'ced_scw_shopify_store_locations', $store_locations['locations'] );
			}
			die;
		}
	}

	/**
	 * Ced_scw_save_selected_location
	 *
	 * @return void
	 */
	public function ced_scw_save_selected_location() {
		$check_ajax = check_ajax_referer( 'ced-shopify-ajax-seurity-string', 'nonce' );
		if ( $check_ajax ) {
			$sanitized     = filter_input_array( INPUT_POST );
			$location_id   = isset( $sanitized['location_id'] ) ? sanitize_text_field( ( $sanitized['location_id'] ) ) : '';
			$location_name = isset( $sanitized['location_name'] ) ? sanitize_text_field( ( $sanitized['location_name'] ) ) : '';

			if ( ! empty( $location_id ) ) {
				update_option( 'ced_scw_selected_location_id', $location_id );
			}
			die;
		}
	}

	/**
	 * Ced_scw_update_inventory_on_shopify
	 *
	 * @param  mixed $order_id
	 * @param  mixed $order
	 * @return void
	 */
	public function ced_scw_update_inventory_on_shopify( $order_id, $order ) {
		global $wpdb;
		if ( $order_id ) {
			$key_exists = $wpdb->get_var( $wpdb->prepare( "SELECT post_id FROM $wpdb->postmeta WHERE $wpdb->posts.ID=%s AND meta_key=%s AND meta_value=%s LIMIT 1", "$order_id", 'ced_check_isit_shopify_order', 'shopify' ) );
			if ( $key_exists ) {
				return;
			}
		}

		require_once CED_SCW_PATH . 'includes/shopify/class-ced-shopify-server-response.php';
		$ced_shopify_server_obj = Ced_Shopify_Server_Response::get_instance();
		$render_settings_data   = get_option( 'ced_shopify_settings_data', false );

		if ( isset( $render_settings_data['store_address'] ) && isset( $render_settings_data['access_token'] ) ) {
			$ced_store_address = $render_settings_data['store_address'];
			$ced_access_token  = $render_settings_data['access_token'];
		}

		$params                 = array();
		$params['domain']       = home_url();
		$params['shop_url']     = ! empty( $ced_store_address ) ? $ced_store_address : '';
		$params['access_token'] = ! empty( $ced_access_token ) ? $ced_access_token : '';
		$params['channel']      = 'shopify';

		$orders_data               = $order->get_data();
		$stock_prepare_data        = array();
		$prepare_to_update_product = array();

		$settings_data = get_option( 'ced_shopify_settings_data' );

		if ( isset( $settings_data['enable_order_export'] ) && 'on' === $settings_data['enable_order_export'] ) {
			foreach ( $orders_data['line_items'] as $key => $item ) {
				$product_dat   = $item->get_product();
				$product_id    = $item->get_product_id();
				$variation_id  = $item->get_variation_id();
				$item_quantity = $item->get_quantity();
				$item_total    = $item->get_total();
				$item_name     = $item->get_name();

				$product_id           = isset( $variation_id ) && $variation_id > 0 ? $variation_id : $product_id;
				$inventory_item_id    = get_post_meta( $product_id, 'ced_swc_inventory_item_id', true );
				$selected_location_id = get_option( 'ced_scw_selected_location_id' );
				$shopify_ID           = get_post_meta( $product_id, 'ced_swc_shopifyVariationItemId', true );

				$stock_prepare_data[] = array(
					'location_id'          => $selected_location_id,
					'inventory_item_id'    => $inventory_item_id,
					'available_adjustment' => '-' . $item_quantity,
				);

				if ( is_object( $product_dat ) && ! empty( $shopify_ID ) ) {
					$item_price   = $product_dat->get_price();
					$line_items[] = array(
						'variant_id' => $shopify_ID,
						'price'      => $item_price,
						'quantity'   => $item_quantity,
						'title'      => $item_name,
						'name'       => $item_name,
					);
				}
			}

			$billing_address = array(
				'first_name' => isset( $orders_data['billing']['first_name'] ) ? $orders_data['billing']['first_name'] : '',
				'last_name'  => isset( $orders_data['billing']['last_name'] ) ? $orders_data['billing']['last_name'] : '',
				'email'      => isset( $orders_data['billing']['email'] ) ? $orders_data['billing']['email'] : '',
				'phone'      => isset( $orders_data['billing']['phone'] ) ? $orders_data['billing']['phone'] : '',
				'address1'   => $orders_data['billing']['address_1'] . ' ' . $orders_data['billing']['address_2'],
				'city'       => isset( $orders_data['billing']['city'] ) ? $orders_data['billing']['city'] : '',
				'province'   => isset( $orders_data['billing']['state'] ) ? $orders_data['billing']['state'] : '',
				'zip'        => isset( $orders_data['billing']['postcode'] ) ? $orders_data['billing']['postcode'] : '',
				'country'    => isset( $orders_data['billing']['country'] ) ? $orders_data['billing']['country'] : '',
			);

			$shipping_address = array(
				'first_name' => isset( $orders_data['shipping']['first_name'] ) ? $orders_data['shipping']['first_name'] : '',
				'last_name'  => isset( $orders_data['shipping']['last_name'] ) ? $orders_data['shipping']['last_name'] : '',
				'phone'      => isset( $orders_data['shipping']['phone'] ) ? $orders_data['shipping']['phone'] : '',
				'address1'   => $orders_data['shipping']['address_1'] . ' ' . $orders_data['shipping']['address_2'],
				'city'       => isset( $orders_data['shipping']['city'] ) ? $orders_data['shipping']['city'] : '',
				'province'   => isset( $orders_data['shipping']['state'] ) ? $orders_data['shipping']['state'] : '',
				'zip'        => isset( $orders_data['shipping']['postcode'] ) ? $orders_data['shipping']['postcode'] : '',
				'country'    => isset( $orders_data['shipping']['country'] ) ? $orders_data['shipping']['country'] : '',
			);

			$customer = array(
				'first_name' => isset( $orders_data['billing']['first_name'] ) ? $orders_data['billing']['first_name'] : '',
				'last_name'  => isset( $orders_data['billing']['last_name'] ) ? $orders_data['billing']['last_name'] : '',
				'email'      => isset( $orders_data['billing']['email'] ) ? $orders_data['billing']['email'] : '',
			);

			$shopify_note    = 'From WooCommerce Site Order #' . $order_id;
			$source_of_order = 'WooCommerce Site';
			$order_tags      = array(
				$source_of_order,
				'#' . $order_id,
			);

			$prepare_data['order']['line_items']       = $line_items;
			$prepare_data['order']['customer']         = $customer;
			$prepare_data['order']['billing_address']  = $billing_address;
			$prepare_data['order']['shipping_address'] = $shipping_address;
			$prepare_data['order']['note']             = $shopify_note;
			$prepare_data['order']['tags']             = $order_tags;

			foreach ( $order->get_used_coupons() as $coupon_code ) {
				$coupon         = new WC_Coupon( $coupon_code );
				$discount_codes = array(
					'code'   => $coupon->get_code(),
					'amount' => $coupon->get_amount(),
					'type'   => $coupon->get_discount_type(),
				);
			}
			$prepare_data['order']['discount_codes'][] = $discount_codes;

			$shipping_price  = $order->get_shipping_total();
			$shipping_method = $order->get_shipping_method();

			if ( ! empty( $shipping_price ) || 0 == $shipping_price ) {
				$total_shipping_price_set                  = array(
					'code'  => 'shipping',
					'title' => ! empty( $shipping_method ) ? $shipping_method : 'shipping',
					'price' => $shipping_price,
				);
				$prepare_data['order']['shipping_lines'][] = $total_shipping_price_set;
			}

			$prepare_data['order']['email']            = $orders_data['billing']['email'];
			$prepare_data['order']['financial_status'] = 'paid';

			if ( ! empty( $line_items ) ) {
				$encode_product_data    = json_encode( $prepare_data );
				$params['functionType'] = 'createOrderOnShopify';
				$params['encodedData']  = $encode_product_data;
				$response               = $ced_shopify_server_obj->get_server_response_data( $params );

				if ( isset( $response['order'] ) && ! empty( $response['order'] ) ) {
					$shopify_order_id = isset( $response['order']['id'] ) ? $response['order']['id'] : '';

					if ( ! empty( $shopify_order_id ) ) {
						update_post_meta( $order_id, 'ced_swc_ced_shopify_order_id', $shopify_order_id );
					}

					foreach ( $stock_prepare_data as $key => $value ) {
						$encode_product_data    = json_encode( $value );
						$params['functionType'] = 'updateProductStockOnShopify';
						$params['encodedData']  = $encode_product_data;
						$response               = $ced_shopify_server_obj->get_server_response_data( $params );
					}
				}
			}
		}
	}

	/**
	 * Ced_scw_cronSchedules
	 *
	 * @param  mixed $schedules
	 * @return void
	 */
	public function ced_scw_cronSchedules( $schedules ) {
		if ( ! isset( $schedules['ced_scw_5min'] ) ) {
			$schedules['ced_scw_5min'] = array(
				'interval' => 5 * 60,
				'display'  => __( 'Once every 5 minutes' ),
			);
		}
		if ( ! isset( $schedules['ced_scw_10min'] ) ) {
			$schedules['ced_scw_10min'] = array(
				'interval' => 10 * 60,
				'display'  => __( 'Once every 10 minutes' ),
			);
		}
		if ( ! isset( $schedules['ced_scw_15min'] ) ) {
			$schedules['ced_scw_15min'] = array(
				'interval' => 15 * 60,
				'display'  => __( 'Once every 15 minutes' ),
			);
		}
		return $schedules;
	}

	/**
	 * Ced_scw_set_schedules
	 *
	 * @return void
	 */
	public function ced_scw_set_schedules() {
		$render_settings_data = get_option( 'ced_shopify_settings_data', false );
		$update_description   = isset( $render_settings_data['update_description'] ) ? sanitize_text_field( $render_settings_data['update_description'] ) : '';
		$update_stock         = isset( $render_settings_data['update_stock'] ) ? sanitize_text_field( $render_settings_data['update_stock'] ) : '';
		$update_price         = isset( $render_settings_data['update_price'] ) ? sanitize_text_field( $render_settings_data['update_price'] ) : '';

		if ( 'on' == $update_description || 'on' == $update_stock || 'on' == $update_price ) {
			$isShceduled = wp_get_schedule( 'ced_scw_auto_sync_existing_products' );
			if ( ! $isShceduled ) {
				wp_schedule_event( time(), 'ced_scw_5min', 'ced_scw_auto_sync_existing_products' );
			} elseif ( '' == $update_description && '' == $update_stock && '' == $update_price ) {
				wp_clear_scheduled_hook( 'ced_scw_auto_sync_existing_products' );
			}
		}
	}

	/**
	 * Ced_scw_auto_sync_from_shopify
	 *
	 * @return void
	 */
	public function ced_scw_auto_sync_from_shopify() {
		require_once CED_SCW_PATH . 'includes/shopify/class-ced-shopify-server-response.php';
		$ced_shopify_server_obj  = Ced_Shopify_Server_Response::get_instance();
		$ced_shopify_product_obj = Ced_Shopify_Product::get_instance();
		$render_settings_data    = get_option( 'ced_shopify_settings_data', false );

		if ( isset( $render_settings_data['store_address'] ) && isset( $render_settings_data['access_token'] ) ) {
			$ced_store_address = $render_settings_data['store_address'];
			$ced_access_token  = $render_settings_data['access_token'];
		}

		$params                 = array();
		$params['domain']       = home_url();
		$params['shop_url']     = ! empty( $ced_store_address ) ? $ced_store_address : '';
		$params['access_token'] = ! empty( $ced_access_token ) ? $ced_access_token : '';
		$params['channel']      = 'shopify';
		$params['functionType'] = 'getProductDataFromShopify';

		$store_products = array();
		$page           = get_option( 'ced_scw_synced_page_number', '' );

		if ( '' == $page ) {
			$page = 1;
		} else {
			$page++;
		}

		$store_products = get_posts(
			array(
				'numberposts'  => 10,
				'post_type'    => 'product',
				'post_status'  => array( 'publish', 'draft' ),
				'meta_key'     => 'ced_swc_shopifyItemId',
				'meta_compare' => 'EXISTS',
				'fields'       => 'ids',
				'paged'        => $page,
			)
		);

		if ( empty( $store_products ) ) {
			delete_option( 'ced_scw_synced_page_number' );
		}

		if ( ! empty( $store_products ) ) {
			foreach ( $store_products as $key => $productId ) {
				$shopify_product_id    = get_post_meta( $productId, 'ced_swc_shopifyItemId', true );
				$params['encodedData'] = $shopify_product_id;
				$productData           = $ced_shopify_server_obj->get_server_response_data( $params );

				if ( ! empty( $productData ) ) {
					$productData = isset( $productData['product'] ) ? $productData['product'] : $productData;
					update_post_meta( $productId, 'ced_swc_productData', $productData );

					$update_description = isset( $render_settings_data['update_description'] ) ? sanitize_text_field( $render_settings_data['update_description'] ) : '';
					if ( ! empty( $update_description ) && 'on' == $update_description ) {
						$my_post = array(
							'ID'           => $productId,
							'post_title'   => $productData['title'],
							'post_status'  => 'active' == $productData['status'] ? 'publish' : 'draft',
							'post_content' => isset( $productData['body_html'] ) ? $productData['body_html'] : '',
						);
						wp_update_post( $my_post );
					}

					if ( isset( $productData['options'] ) && ! empty( $productData['options'] ) ) {
						if ( 1 == count( $productData['variants'] ) ) {
							$ced_shopify_product_obj->ced_swc_update_as_simple_product( $productId, $productData['variants'][0], $render_settings_data, '' );
						} else {
							$variation_attributes = isset( $productData['options'] ) ? $productData['options'] : array();
							$variations           = isset( $productData['variants'] ) ? $productData['variants'] : array();
							$ced_shopify_product_obj->ced_swc_update_as_variable_product( $productId, $variations, $productData, $render_settings_data, '' );
						}
					}

					$force_update_product = wc_get_product( $productId );
					$force_update_product->save();
				}

				update_option( 'ced_scw_synced_page_number', $page );
			}
		}
	}

	/**
	 * Ced_swc_add_table_columns
	 *
	 * @param  mixed $columns
	 * @return void
	 */
	public function ced_swc_add_table_columns( $columns ) {
		$columns['ced_swc_additional'] = 'Actions';
		return $columns;
	}

	/**
	 * Ced_swc_manage_table_columns
	 *
	 * @param  mixed $column_name
	 * @param  mixed $productId
	 * @return void
	 */
	public function ced_swc_manage_table_columns( $column_name, $productId ) {
		$shopify_product_id = get_post_meta( $productId, 'ced_swc_shopifyItemId', true );
		$classname          = 'ced_spinner_' . $shopify_product_id . ' spinner';
		$classname_notice   = 'ced_swc_notice_' . $shopify_product_id;

		if ( 'ced_swc_additional' == $column_name && ! empty( $productId ) ) {
			?>
				<div class="ced_swc_extra_actions">
					<ul>
						<li>
							<a href="javascript:void(0)" class="" id="ced_swc_instant_sync" data-shopify_id="<?php echo esc_attr( $shopify_product_id ); ?>" data-productid="<?php echo esc_attr( $productId ); ?>"><?php esc_html_e( 'Instant sync', ' shopify-connector-for-woocommerce' ); ?></a>
							<span class="<?php echo esc_attr( $classname ); ?>"></span>
							<div class="<?php echo esc_attr( $classname_notice ); ?>"></div>
						</li>
					</ul>
				</div>
			<?php
		}
	}

	/**
	 * Ced_swc_instant_sync_using_action
	 *
	 * @return void
	 */
	public function ced_swc_instant_sync_using_action() {
		$check_ajax = check_ajax_referer( 'ced-shopify-ajax-seurity-string', 'nonce' );
		if ( $check_ajax ) {
			$shopify_id = isset( $_POST['shopify_id'] ) ? sanitize_text_field( wp_unslash( $_POST['shopify_id'] ) ) : '';
			$productId  = isset( $_POST['productId'] ) ? sanitize_text_field( wp_unslash( $_POST['productId'] ) ) : '';

			require_once CED_SCW_PATH . 'includes/shopify/class-ced-shopify-server-response.php';
			$ced_shopify_server_obj  = Ced_Shopify_Server_Response::get_instance();
			$ced_shopify_product_obj = Ced_Shopify_Product::get_instance();
			$render_settings_data    = get_option( 'ced_shopify_settings_data', false );

			if ( isset( $render_settings_data['store_address'] ) && isset( $render_settings_data['access_token'] ) ) {
				$ced_store_address = $render_settings_data['store_address'];
				$ced_access_token  = $render_settings_data['access_token'];
			}

			$params                       = array();
			$params['domain']             = home_url();
			$params['access_token']       = ! empty( $ced_access_token ) ? $ced_access_token : '';
			$params['shop_url']           = ! empty( $ced_store_address ) ? $ced_store_address : '';
			$params['shopify_product_id'] = ! empty( $shopify_id ) ? $shopify_id : '';
			$params['channel']            = 'shopify';
			$params['functionType']       = 'getSingleProductDataFromShopify';
			$productData                  = $ced_shopify_server_obj->get_server_response_data( $params );

			if ( ! empty( $productData ) && ! empty( $productData['product'] ) ) {
				update_post_meta( $productId, 'ced_swc_productData', $productData );
				$productData = isset( $productData['product'] ) ? $productData['product'] : $productData;
				$my_post     = array(
					'ID'           => $productId,
					'post_title'   => $productData['title'],
					'post_status'  => 'active' == $productData['status'] ? 'publish' : 'draft',
					'post_content' => isset( $productData['body_html'] ) ? $productData['body_html'] : '',
				);
				wp_update_post( $my_post );

				if ( isset( $productData['options'] ) && ! empty( $productData['options'] ) ) {
					if ( 1 == count( $productData['variants'] ) ) {
						$ced_shopify_product_obj->ced_swc_update_as_simple_product( $productId, $productData['variants'][0], $render_settings_data, 'swc_manual' );
					} else {
						$variation_attributes = isset( $productData['options'] ) ? $productData['options'] : array();
						$variations           = isset( $productData['variants'] ) ? $productData['variants'] : array();
						$ced_shopify_product_obj->ced_swc_update_as_variable_product( $productId, $variations, $productData, $render_settings_data, 'swc_manual' );
					}
				}

				$force_update_product = wc_get_product( $productId );
				$force_update_product->save();

				echo json_encode(
					array(
						'status'  => '200',
						'message' => 'Updated',
					)
				);
				die;
			} else {
				echo json_encode(
					array(
						'status'  => '400',
						'message' => 'Error: ' . $productData['errors'],
					)
				);
				die;
			}
		}
	}

}
