(function( $ ) {
	'use strict';

	/**
	 * All of the code for your admin-facing JavaScript source
	 * should reside in this file.
	 *
	 * Note: It has been assumed you will write jQuery code here, so the
	 * $ function reference has been prepared for usage within the scope
	 * of this function.
	 *
	 * This enables you to define handlers, for when the DOM is ready:
	 *
	 * $(function() {
	 *
	 * });
	 *
	 * When the window is loaded:
	 *
	 * $( window ).load(function() {
	 *
	 * });
	 *
	 * ...and/or other possibilities.
	 *
	 * Ideally, it is not considered best practise to attach more than a
	 * single DOM-ready or window-load handler for a particular page.
	 * Although scripts in the WordPress core, Plugins and Themes may be
	 * practising this, we should strive to set a better example in our own work.
	*/

	jQuery( document ).on(
		'click',
		'#ced_shopify_dashboard_submit',
		function(){
			var ced_shopify_current_url = jQuery( '.ced_shopify_importer_current_url' ).val();
			var ced_new_url             = ced_shopify_current_url + '&section=setting-page&platform=shopify';
			window.location.href        = ced_new_url;
		}
	);

	// Validate Token
	jQuery( document ).on(
		'click',
		'#ced_shopify_verfiy_token',
		function(e) {
			e.preventDefault();
			jQuery( '.ced_scw_shopify_connector_loader' ).show();
			var shop_url     = jQuery( '#shopify_store_address' ).val();
			var access_token = jQuery( '#shopify_access_token' ).val();
			jQuery( '#ced_shopify_verfiy_token_status' ).text( '' );
			jQuery.ajax(
				{
					url 	: Ced_Shopify_connector_action_handler.ajax_url,
					type	: 'post',
					data	: {
						nonce	     : Ced_Shopify_connector_action_handler.ajax_nonce,
						shop_url     : shop_url,
						access_token : access_token,
						action	     : "ced_scw_validate_token"
					},
					success : function( response ) {
						response = JSON.parse( response );
						if ( response.code == '400' ) {
							jQuery( '.ced_scw_shopify_connector_loader' ).hide();
							jQuery( '#ced_shopify_verfiy_token_status' ).text( response.message );
						} else if ( response.code == '200' ) {
							jQuery( '.ced_scw_shopify_connector_loader' ).hide();
							jQuery( '#ced_shopify_verfiy_token_status' ).css( 'color','green' );
							jQuery( '#ced_shopify_verfiy_token_status' ).text( response.message );
						}
					}
				}
			);
		}
	);

	// Fetching the shopify collection
	jQuery( document ).on(
		'click',
		'#ced_shopify_fetch_collection',
		function(e) {
			e.preventDefault();
			jQuery( '.ced_scw_shopify_connector_loader' ).show();
			var shopify_collection_type 	= 'custom_collections';
			var shopify_collection_since_id = 0;

			ced_scw_fetch_shopify_collections( shopify_collection_type, shopify_collection_since_id );
		}
	);

	function ced_scw_fetch_shopify_collections( shopify_collection_type, shopify_collection_since_id ) {
		jQuery.ajax(
			{
				url 	: Ced_Shopify_connector_action_handler.ajax_url,
				type	: 'post',
				data	: {
					nonce						: Ced_Shopify_connector_action_handler.ajax_nonce,
					shopify_collection_type		: shopify_collection_type,
					shopify_collection_since_id : shopify_collection_since_id,
					action						: "ced_scw_fetch_shopify_collection_recursive"
				},
				success : function( response ) {
					var parsed_response 			= jQuery.parseJSON( response );
					var execution 					= parsed_response.execution;
					var shopify_shop_url 			= parsed_response.shopify_admin_store_url
					var shopify_collection_since_id = parsed_response.shopify_collection_sinceID;
					var shopify_collection_type 	= parsed_response.shopify_collection_type

					if ( execution == "continue" ) {
						ced_scw_fetch_shopify_collections( shopify_collection_type, shopify_collection_since_id );
					} else {
						jQuery.ajax(
							{
								url 	: Ced_Shopify_connector_action_handler.ajax_url,
								type	: 'post',
								data	: {
									nonce	: Ced_Shopify_connector_action_handler.ajax_nonce,
									action	: "ced_scw_fetch_shopify_stored_collection"
								},
								success : function( response ) {
									jQuery( '.ced-scw-collections' ).html( "" );
									jQuery( '.ced-scw-collections' ).append( response );
								}
							}
						);
						jQuery( '.ced_scw_shopify_connector_loader' ).hide();
					}

				}
			}
		);
	}

	// Select plan
	jQuery( document ).on(
		'click',
		'.ced_plan_selection_button',
		function(e) {
			e.preventDefault();
			jQuery( '.ced_scw_shopify_connector_loader' ).show();

			var plan_type   = jQuery( this ).attr( 'data-plan_name' );
			var plan_cost   = jQuery( this ).attr( 'data-plan_cost' );
			var contract_id = jQuery( this ).attr( 'data-contract_id' );
			var plan_period = jQuery( '.ced_scw_plan_type_option' ).val();
			jQuery.ajax(
				{
					url 	: Ced_Shopify_connector_action_handler.ajax_url,
					type	: 'post',
					data	: {
						nonce		: Ced_Shopify_connector_action_handler.ajax_nonce,
						plan_type	: plan_type,
						plan_cost	: plan_cost,
						contract_id	: contract_id,
						plan_period	: plan_period,
						nonce       : Ced_Shopify_connector_action_handler.ajax_nonce,
						action		: "ced_scw_pricing_plan_selection"
					},
					success : function( response ) {
						var parsed_response  = jQuery.parseJSON( response );
						var message 		 = parsed_response.message;
						var status_resp 	 = parsed_response.status;
						var confirmation_url = parsed_response.confirmation_url;
						if (confirmation_url != "") {
							window.location.href = confirmation_url;
						}
					}
				}
			)

		}
	)
	jQuery( document ).on(
		'change',
		'.ced_scw_marketplace_option',
		function(e) {
			e.preventDefault();
			jQuery( '.ced_scw_shopify_connector_loader' ).show();

			var marketplace       = jQuery( this ).val();
			window.location.href += '&product_plan=' + marketplace;
		}
	)
	jQuery( document ).on(
		'click',
		'.ced_scw_cancel_plan',
		function(e) {
			e.preventDefault();
			if (confirm( "Are you sure you want to cancel the ongoing plan?\n \n Note : You can still use the plan for the remaining subscribed days." )) {
				jQuery( '.ced_scw_shopify_connector_loader' ).show();
				var contract_id = jQuery( this ).attr( 'data-contract_id' );
				jQuery.ajax(
					{
						url 	: Ced_Shopify_connector_action_handler.ajax_url,
						type	: 'post',
						data	: {
							nonce		: Ced_Shopify_connector_action_handler.ajax_nonce,
							contract_id	: contract_id,
							action		: "ced_scw_pricing_plan_cancellation"
						},
						success : function( response ) {
							var parsed_response = jQuery.parseJSON( response );
							var message         = parsed_response.message;
							window.location.reload();
						}
					}
				)
			} else {
				return;
			}

		}
	)
	jQuery( document ).on(
		'click',
		'.ced_scw_change_plan',
		function(e) {
			e.preventDefault();
			jQuery( '.ced_scw_shopify_connector_loader' ).show();
			window.location.href += '&is_update=yes';
		}
	)
	jQuery( document ).on(
		'change',
		'.ced_scw_plan_type_option',
		function(e) {
			e.preventDefault();
			var plan_type = jQuery( this ).val();
			jQuery( '.ced_scw_shopify_connector_loader' ).show();
			window.location.href += '&plan_type=' + plan_type;
		}
	)

	jQuery( document ).on(
		'click',
		'#ced_shopify_get_location_list',
		function(e) {
			e.preventDefault();
			jQuery( '.ced_scw_shopify_connector_loader' ).show();
			jQuery.ajax(
				{
					url 	: Ced_Shopify_connector_action_handler.ajax_url,
					type	: 'post',
					data	: {
						nonce		: Ced_Shopify_connector_action_handler.ajax_nonce,
						action		: "ced_scw_fetch_locations"
					},
					success : function() {
						window.location.reload();
					}
				}
			)
		}
	)

	jQuery( document ).on(
		'change',
		'#ced_scw_select_location',
		function() {
			jQuery( '.ced_scw_shopify_connector_loader' ).show();
			var location_name = jQuery( "#ced_scw_select_location option:selected" ).text();
			var location_id   = jQuery( "#ced_scw_select_location" ).val();

			jQuery.ajax(
				{
					url 	: Ced_Shopify_connector_action_handler.ajax_url,
					type	: 'post',
					data	: {
						nonce			: Ced_Shopify_connector_action_handler.ajax_nonce,
						location_id		: location_id,
						location_name 	: location_name,
						action			: "ced_scw_save_selected_location"
					},
					success : function() {
						jQuery( '.ced_scw_shopify_connector_loader' ).hide();
					}
				}
			)
		}
	)

	jQuery( document ).on(
		'click',
		'#ced_swc_instant_sync',
		function(e) {
			var shopify_id = jQuery( this ).data( 'shopify_id' );
			var productId  = jQuery( this ).data( 'productid' );

			jQuery( '.ced_spinner_' + shopify_id ).css( 'visibility' , 'visible' );
			jQuery.ajax(
				{
					url 	: Ced_Shopify_connector_action_handler.ajax_url,
					type 	: 'post',
					data 	: {
						nonce		: Ced_Shopify_connector_action_handler.ajax_nonce,
						action 		: 'ced_swc_instant_sync_using_action',
						shopify_id	: shopify_id,
						productId	: productId,
					},
					success : function(response) {
						jQuery( '.ced_spinner_' + shopify_id ).css( 'visibility' , 'hidden' );
						var parsed_response = jQuery.parseJSON( response );
						var status         	= parsed_response.status;
						var message         = parsed_response.message;

						if ( '200' == status ) {
							jQuery( '.ced_swc_notice_' + shopify_id ).html( "" );
							jQuery( '.ced_swc_notice_' + shopify_id ).css( 'color' , 'green' );
							jQuery( '.ced_swc_notice_' + shopify_id ).append( message );
						} else {
							jQuery( '.ced_swc_notice_' + shopify_id ).html( "" );
							jQuery( '.ced_swc_notice_' + shopify_id ).css( 'color' , 'red' );
							jQuery( '.ced_swc_notice_' + shopify_id ).append( message );
						}
						setTimeout( function(){window.location.reload( 1 );}, 1000 );
					}
				}
			);
		}
	);
})( jQuery );
