<?php
/**
 * Pricing Plan file
 *
 * This file is used to set the pricing plans.
 *
 * @link       https://cedcommerce.com
 * @since      1.0.0
 *
 * @package    Shopify_Connector_For_Woocommerce
 * @subpackage Shopify_Connector_For_Woocommerce/admin/partials
 */

/** If this file is called directly, abort. */
if ( ! defined( 'WPINC' ) ) {
	die;
}
$product_data = ! empty( $_GET['product_plan'] ) ? sanitize_text_field( wp_unslash( $_GET['product_plan'] ) ) : '';
$plan_type    = ! empty( $_GET['plan_type'] ) ? sanitize_text_field( wp_unslash( $_GET['plan_type'] ) ) : 'monthly';
$is_update    = ! empty( $_GET['is_update'] ) ? sanitize_text_field( wp_unslash( $_GET['is_update'] ) ) : 'no';
$product_plan = ! empty( $_GET['product_plan'] ) ? sanitize_text_field( wp_unslash( $_GET['product_plan'] ) ) : '';
$plan_options = array( 'monthly', 'yearly' );
$plan_html    = '';
foreach ( $plan_options as $key => $value ) {
	if ( $value === $plan_type ) {
		$selected = 'selected';
	} else {
		$selected = '';
	}
	$plan_html .= '<option value="' . $value . '" ' . $selected . '>' . ucfirst( $value ) . '</option>';
}

$plan_data   = file_get_contents( 'https://woodemo.cedcommerce.com/wooapi/ced_pricing_plan_options.json' );
$prod_data   = array();
$contract_id = '';
if ( ! empty( $plan_data ) ) {
	$plan_data = json_decode( $plan_data, true );
	if ( ! empty( $product_data ) ) {
		$prod_data = $plan_data[ $product_data ][ $plan_type ];
	}
}
$select_data = '';
$menus       = apply_filters( 'ced_scw_add_saas_marketplace_array', array() );
if ( is_array( $menus ) && ! empty( $menus ) ) {
	$select_data = '<select class="ced_scw_marketplace_option"><option value"">--Select--</option>';
	foreach ( $menus as $k_data => $v_data ) {
		if ( $product_plan === $k_data ) {
			$selected = 'selected';
		} else {
			$selected = '';
		}
		$select_data .= '<option value="' . $k_data . '" ' . $selected . '>' . $v_data . '</option>';
	}
	$select_data .= '<select>';
}
?>

<!-- This snippet uses Font Awesome 5 Free as a dependency. You can download it at fontawesome.io! -->
<div class="ced_scw_shopify_connector_loader">
	<img src="<?php echo esc_url( CED_SCW_URL . 'admin/images/loading.gif' ); ?>" width="50px" height="50px" class="ced_shopify_loading_img" >
</div>
<section class="pricing py-5">
	<div class="ced_scw_header">
	<div class="ced_scw_header_marketplace_div custom-select">
		<span class="ced_scw_header_marketplace">Select Marketplace : <?php print_r( $select_data ); ?>
		</span>
	</div>
	<div class="ced_scw_header_plan_type_div custom-select">
		<span class="ced_scw_header_plan_type">Select Plan Type : 
		<select class="ced_scw_plan_type_option">
			<?php print_r( $plan_html ); ?>
		</select>
		</span>
	</div>
	</div>
	<div class="container">
	<div class="row">
<?php
if ( ! empty( $prod_data ) ) {
	$pricing_subscribed = get_option( 'ced_scw_pricing_selected' );
	$subscribed_data    = get_option( 'ced_saas_contract_details', '' );
	$status_is          = '';
	if ( is_array( $subscribed_data ) && ! empty( $subscribed_data ) ) {
		$subscribed_data   = $subscribed_data[ $product_data ];
		$status_is         = ! empty( $subscribed_data['plan_status'] ) ? $subscribed_data['plan_status'] : '';
		$next_payment_date = ! empty( $subscribed_data['next_payment_date'] ) ? $subscribed_data['next_payment_date'] : '';
		$end_date          = ! empty( $subscribed_data['end_date'] ) ? $subscribed_data['end_date'] : '';
	}
	$cancelled   = '';
	$status_html = '';
	if ( 'active' === $status_is ) {
		$status_html = "<span style='color:green'>Active</span>";
	} elseif ( 'pending' === $status_is ) {
		$status_html = "<span style='color:yellow'>Pending</span>";
	} elseif ( 'canceled' === $status_is ) {
		$status_html = "<span style='color:red'>Canceled</span>";
	}
	if ( ! empty( $end_date ) ) {
		$current_date = strtotime( gmdate( 'Y-m-d h:i:s' ) );
		$end_date_str = strtotime( $end_date );
		if ( $current_date >= $end_date_str ) {
			$next_html = '<p style="margin-top: 20px;">Current plan is already expired on <span style="color:red;"><b>' . $end_date . '</b></span>. Please Renew it to continue the services.</p>';
		} else {
			$next_html = '<p style="margin-top: 20px;">Current plan is expiring on <span style="color:red;"><b>' . $end_date . '</b></span>. Please Renew it to continue the services.</p>';
		}
	} elseif ( 'canceled' == $status_is ) {
		$cancelled = 'disabled';
		$next_html = '<p style="margin-top: 20px;">Current plan is expiring on <span style="color:red;"><b>' . $next_payment_date . '</b></span>. Please Renew it to continue the services.</p>';
	} elseif ( ! empty( $next_payment_date ) ) {
		$next_html = '<p style="margin-top: 20px;">Your next subscription payment is scheduled on <span style="color:green;"><b>' . $next_payment_date . '</b></span>.</p>';
	} else {
		$next_html = '';
	}
	if ( 'true' !== $pricing_subscribed || 'no' !== $is_update ) {
		if ( 'yes' === $is_update ) {
			$contract_id = $subscribed_data['contract_id'];
		}
		foreach ( $prod_data as $key => $plan ) {
			echo '<div class="col-lg-3">
          <div class="card mb-5 mb-lg-0">
            <div class="card-body">
              <h5 class="card-title text-muted text-uppercase text-center">' . esc_attr( $plan['plan_name'] ) . '</h5>
              <h6 class="card-price text-center">$' . esc_attr( $plan['plan_price'] ) . '<span class="period">/month</span></h6>';
			if ( 'yearly' === $plan_type ) {
				echo '<span class="ced_plan_meta_info" style="position: absolute;left: 42%;font-size: 12px;opacity: 0.6;">* Billed annually</span>';
			}
			echo '<hr>
            <ul class="fa-ul">';
			$desc = explode( ',', $plan['plan_description'] );
			if ( is_array( $desc ) && ! empty( $desc ) ) {
				foreach ( $desc as $k => $v ) {
					echo '<li><span class="fa-li"><i class="fas fa-check"></i></span><strong>' . esc_attr( $v ) . '</strong>
                </li>';
				}
			}
			echo '</ul>
              <div class="d-grid">
                <a href="#" class="btn btn-primary text-uppercase ced_plan_selection_button" data-plan_name="' . esc_attr( $plan['plan_name'] ) . '" data-plan_cost="' . esc_attr( $plan['price_total'] ) . '" data-contract_id="' . esc_attr( $contract_id ) . '">Get Plan</a>
              </div>
            </div>
          </div>
        </div>';
		}
		?>
	</div>
	<div id="free_trial_notice"><span>* Free trial for 7 days from the day of plan subscription. Paid plan will commence once free trial expires.</span></div>
	</div>
</section>
		<?php
	} else {
		echo '<p><span>Current Subscribed Plan : <b>' . esc_attr( strtoupper( $subscribed_data['plan_name'] ) ) . '(' . esc_attr( ucfirst( $subscribed_data['billing_period'] ) ) . ')</b> ' . wp_kses_post( $status_html ) . '<span><span><button class="button-primary ced_scw_change_plan">Change Plan</button></span><button class="button-primary ced_scw_cancel_plan" data-contract_id="' . esc_attr( $subscribed_data['contract_id'] ) . '" ' . esc_attr( $cancelled ) . '>Cancel Plan</button></span></p><p>' . wp_kses_post( $next_html ) . '</p><div id="free_trial_notice" style="margin-top: 70px;"><span>* Free trial for 7 days from the day of plan subscription. Paid plan will commence once free trial expires.</span></div>';
	}
} else {
	echo 'No Plans to Show. Please choose atleast 1 Marketplace to start.';
}

