<?php
/**
 * Customers
 *
 * @link       https://cedcommerce.com
 * @since      1.0.0
 *
 * @package    Shopify_Connector_For_Woocommerce
 * @subpackage Shopify_Connector_For_Woocommerce/includes/shopify
 */

if ( ! class_exists( 'Ced_Shopify_Customers' ) ) {
	/**
	 * Ced_Shopify_Customers
	 *
	 * @since      1.0.0
	 * @package    Shopify_Connector_For_Woocommerce
	 * @subpackage Shopify_Connector_For_Woocommerce/includes/shopify
	 */
	class Ced_Shopify_Customers {

		/**
		 * Declare $_instance.
		 *
		 * @var string
		 */
		private static $_instance;
		/**
		 * Get_instance Instance.
		 *
		 * Ensures only one instance of Ced_Shopify_Customers is loaded or can be loaded.
		 *
		 * @since 1.0.0
		 * @static
		 * @return get_instance instance.
		 */
		public static function get_instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}
		/**
		 * Ced_shopify_prepare_customer_data_to_import.
		 *
		 * @since    1.0.0
		 * @param      int $total_customer Total Customer.
		 * @param      int $left_customer Left Customer.
		 * @param      int $limit Limit.
		 * @param      int $since_id Since ID.
		 * @param      int $customer_log_path Customer log path.
		 */
		public function ced_shopify_prepare_customer_data_to_import( $total_customer, $left_customer, $limit, $since_id, $customer_log_path ) {

			$render_settings_data = get_option( 'ced_shopify_settings_data', false );
			if ( isset( $render_settings_data['store_address'] ) && isset( $render_settings_data['access_token'] ) ) {
				$ced_store_address = $render_settings_data['store_address'];
				$ced_access_token  = $render_settings_data['access_token'];
			}

			require_once CED_SCW_PATH . 'includes/shopify/class-ced-shopify-server-response.php';
			$ced_shopify_server_obj = Ced_Shopify_Server_Response::get_instance();
			$params                 = array();
			$params['domain']       = home_url();
			$params['shop_url']     = ! empty( $ced_store_address ) ? $ced_store_address : '';
			$params['access_token'] = ! empty( $ced_access_token ) ? $ced_access_token : '';
			$params['channel']      = 'shopify';
			$params['functionType'] = 'getTotalCustomerFromStore';
			$total_customer         = $ced_shopify_server_obj->get_server_response_data( $params );

			if ( isset( $total_customer['count'] ) && $total_customer['count'] > 0 ) {

				if ( '' == $since_id ) {
					$since_id = 0;
				}
				$customer_status           = array();
				$customers_limit           = $limit;
				$params['functionType']    = 'getCustomerFromStore';
				$params['since_id']        = $since_id;
				$params['customers_limit'] = $customers_limit;
				$customers                 = $ced_shopify_server_obj->get_server_response_data( $params );

				if ( ! empty( $customers ) ) {

					if ( ! empty( $customers['customers'] ) ) {
						foreach ( $customers['customers'] as $key => $customers_data ) {
							$since_id          = $customers_data['id'];
							$customer_status[] = $this->ced_swc_manage_customers_data_from_shopify( $customers_data );
						}
					}
				}

				$file_open = fopen( $customer_log_path, 'a' );
				foreach ( $customer_status as $status ) {
					fwrite( $file_open, $status . "\n" );
				}
				fclose( $file_open );
				$total_customer = $total_customer['count'];
				if ( '' == $left_customer ) {
					$left_customer = $total_customer;
				}
				$left_customer = $left_customer - $customers_limit;
				if ( $left_customer < 0 ) {
					$left_customer = 0;
				}

				if ( '' == $processed_customer ) {
					$processed_customer = $customers_limit;
				}
				$processed_customer = $total_customer - $left_customer;

				echo json_encode(
					array(
						'status'             => '200',
						'message'            => 'success',
						'total_customer'     => (int) $total_customer,
						'left_customer'      => (int) $left_customer,
						'processed_customer' => (int) $processed_customer,
						'limit'              => (int) $customers_limit,
						'since_id'           => (int) $since_id,
						'customer_status'    => $customer_status,
					)
				);

			} else {
				echo json_encode(
					array(
						'status'  => '400',
						'message' => $total_customer['message'],
					)
				);
				wp_die();
			}

		}
		/**
		 * Ced_swc_manage_customers_data_from_shopify.
		 *
		 * @since    1.0.0
		 * @param    array $customers_data Customers Data.
		 */
		public function ced_swc_manage_customers_data_from_shopify( $customers_data = array() ) {
			if ( is_array( $customers_data ) && ! empty( $customers_data ) ) {

				// Check if user alredy exist by slug email then return.
				if ( get_user_by( 'email', $customers_data['email'] ) ) {
					$customer_status = '( Shopify Customer ID: ' . $customers_data['id'] . ' ) and Email ' . $customers_data['email'] . ' Skipped- Alreday Exists';
					return $customer_status;
				}

				$userdata = array(
					'user_pass'           => mt_rand( 1000000000, 9999999999 ),
					'user_login'          => $customers_data['email'],
					'user_email'          => $customers_data['email'],
					'first_name'          => $customers_data['first_name'],
					'last_name'           => $customers_data['last_name'],
					'description'         => '',
					'rich_editing'        => 'true',
					'syntax_highlighting' => 'true',
				);
				$user_id  = wp_insert_user( $userdata );

				// Here you insert your user data with a 'customer' user role.
				if ( 1 != $user_id ) {
					wp_update_user(
						array(
							'ID'   => $user_id,
							'role' => 'customer',
						)
					);
				}
				$customer_status = 'Customer created (Shopify Customer ID: ' . $customers_data['id'] . ' ) and Email ' . $customers_data['email'];
				// If user Id exist then preparing array to update user meta of 'ID' => $user_id.
				if ( ! empty( $user_id ) ) {
					$update_user_meta = array(
						'billing_first_name'  => $customers_data['default_address']['first_name'],
						'billing_last_name'   => $customers_data['default_address']['last_name'],
						'billing_company'     => $customers_data['default_address']['company'],
						'billing_email'       => $customers_data['email'],
						'billing_phone'       => $customers_data['default_address']['phone'],
						'billing_address_1'   => $customers_data['default_address']['address1'],
						'billing_address_2'   => $customers_data['default_address']['address2'],
						'billing_country'     => $customers_data['default_address']['country'],
						'billing_state'       => $customers_data['default_address']['province'],
						'billing_city'        => $customers_data['default_address']['city'],
						'billing_postcode'    => $customers_data['default_address']['zip'],

						'shipping_first_name' => $customers_data['default_address']['first_name'],
						'shipping_last_name'  => $customers_data['default_address']['last_name'],
						'shipping_address_1'  => $customers_data['default_address']['address1'],
						'shipping_address_2'  => $customers_data['default_address']['address2'],
						'shipping_country'    => $customers_data['default_address']['country'],
						'shipping_state'      => $customers_data['default_address']['province'],
						'shipping_city'       => $customers_data['default_address']['city'],
						'shipping_postcode'   => $customers_data['default_address']['zip'],
					);

					// Update post meta correspoding to User_id.
					foreach ( $update_user_meta as $keys => $values ) {
						update_user_meta( $user_id, $keys, $values );
					}
					$render_settings_data = get_option( 'ced_shopify_settings_data', false );
					if ( isset( $render_settings_data['send_reset_password_email'] ) && 'on' == $render_settings_data['send_reset_password_email'] ) {
						$user       = new WP_User( (int) $user_id );
						$reset_key  = get_password_reset_key( $user );
						$user_login = $user->user_login;
						$rp_link    = '<a href="' . network_site_url( "wp-login.php?action=rp&key=$reset_key&login=" . rawurlencode( $user_login ), 'login' ) . '">Click to Set Password</a>';

						// Sending mail.
						$to      = $customer_data['email'];
						$subject = 'WordPress User Password Reset Link';
						$body    = 'Please click the link to reset your WordPress password<br>' . $rp_link;
						$headers = array( 'Content-Type: text/html; charset=UTF-8' );
						wp_mail( $to, $subject, $body, $headers );

					}
					return $customer_status;
				} else {
					echo 'User Id does not exist';
				}
			}
		}


	}
}
