<?php
/**
 * Orders
 *
 * @link       https://cedcommerce.com
 * @since      1.0.0
 *
 * @package    Shopify_Connector_For_Woocommerce
 * @subpackage Shopify_Connector_For_Woocommerce/includes/shopify
 */

if ( ! class_exists( 'Ced_Shopify_Orders' ) ) {
	/**
	 * Ced_Shopify_Orders
	 *
	 * @since      1.0.0
	 * @package    Shopify_Connector_For_Woocommerce
	 * @subpackage Shopify_Connector_For_Woocommerce/includes/shopify
	 */
	class Ced_Shopify_Orders {
		/**
		 * Declare $_instance.
		 *
		 * @var string
		 */
		private static $_instance;
		/**
		 * Get_instance Instance.
		 *
		 * Ensures only one instance of Ced_Shopify_Product_Helper is loaded or can be loaded.
		 *
		 * @since 1.0.0
		 * @static
		 * @return get_instance instance.
		 */
		public static function get_instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}
		/**
		 * Ced_shopify_create_orders.
		 *
		 * @since    1.0.0
		 * @param      int $total_order Total Order.
		 * @param      int $left_order Left Order.
		 * @param      int $limit Limit.
		 * @param      int $since_id Since ID.
		 * @param      int $order_log_path Order log path.
		 */
		public function ced_shopify_create_orders( $total_order, $left_order, $limit, $since_id, $order_log_path ) {

			$render_settings_data = get_option( 'ced_shopify_settings_data', false );
			if ( isset( $render_settings_data['store_address'] ) && isset( $render_settings_data['access_token'] ) ) {
				$ced_store_address = $render_settings_data['store_address'];
				$ced_access_token  = $render_settings_data['access_token'];
			}

			require_once CED_SCW_PATH . 'includes/shopify/class-ced-shopify-server-response.php';
			$ced_shopify_server_obj = Ced_Shopify_Server_Response::get_instance();
			$params                 = array();
			$params['domain']       = home_url();
			$params['shop_url']     = ! empty( $ced_store_address ) ? $ced_store_address : '';
			$params['access_token'] = ! empty( $ced_access_token ) ? $ced_access_token : '';
			$params['channel']      = 'shopify';
			$params['functionType'] = 'getTotalOrdersFromStore';
			$total_orders           = $ced_shopify_server_obj->get_server_response_data( $params );

			if ( isset( $total_orders['count'] ) && $total_orders['count'] > 0 ) {

				if ( '' == $since_id ) {
					$since_id = 0;
				}

				$orders_limit           = $limit;
				$params['functionType'] = 'getOrdersFromStore';
				$params['since_id']     = $since_id;
				$params['orders_limit'] = $orders_limit;
				$orders                 = $ced_shopify_server_obj->get_server_response_data( $params );

				if ( ! empty( $orders ) ) {
					$order_status = array();
					if ( ! empty( $orders['orders'] ) ) {
						foreach ( $orders['orders'] as $key => $orders_data ) {
							$since_id       = $orders_data['id'];
							$order_status[] = $this->ced_swc_manage_orders_data_from_shopify( $orders_data );
						}
					}

					$file_open = fopen( $order_log_path, 'a' );
					foreach ( $order_status as $status ) {
						fwrite( $file_open, $status . "\n" );
					}
					fclose( $file_open );
					$total_order = $total_orders['count'];
					if ( '' == $left_order ) {
						$left_order = $total_order;
					}
					$left_order = $left_order - $orders_limit;
					if ( $left_order < 0 ) {
						$left_order = 0;
					}

					if ( '' == $processed_order ) {
						$processed_order = $orders_limit;
					}
					$processed_order = $total_order - $left_order;

					echo json_encode(
						array(
							'status'          => '200',
							'message'         => 'success',
							'total_order'     => (int) $total_order,
							'left_order'      => (int) $left_order,
							'processed_order' => (int) $processed_order,
							'limit'           => (int) $orders_limit,
							'since_id'        => (int) $since_id,
							'order_status'    => $order_status,
						)
					);
				}
			} else {
				echo json_encode(
					array(
						'status'  => '400',
						'message' => $total_orders['message'],
					)
				);
				die;
			}
		}
		/**
		 * Ced_swc_manage_orders_data_from_shopify.
		 *
		 * @since    1.0.0
		 * @param      array $orders_data Order data.
		 */
		public function ced_swc_manage_orders_data_from_shopify( $orders_data = array() ) {

			if ( is_array( $orders_data ) && ! empty( $orders_data ) ) {

				if ( 'authorized' == $orders_data['financial_status'] ) {
					$woo_order_status = 'processing';
				} elseif ( 'pending' == $orders_data['financial_status'] ) {
					$woo_order_status = 'pending';
				} elseif ( 'paid' == $orders_data['financial_status'] ) {
					$woo_order_status = 'completed';
				} elseif ( 'partially_paid' == $orders_data['financial_status'] ) {
					$woo_order_status = 'on-hold';
				} elseif ( 'refunded' == $orders_data['financial_status'] ) {
					$woo_order_status = 'refunded';
				} elseif ( 'voided' == $orders_data['financial_status'] ) {
					$woo_order_status = 'cancelled';
				} elseif ( 'partially_refunded' == $orders_data['financial_status'] ) {
					$woo_order_status = 'refunded';
				} elseif ( 'any' == $orders_data['financial_status'] ) {
					$woo_order_status = 'pending';
				} elseif ( 'unpaid' == $orders_data['financial_status'] ) {
					$woo_order_status = 'pending';
				} else {
					$woo_order_status = 'pending';
				}

				$render_settings_data = get_option( 'ced_shopify_settings_data', false );
				if ( isset( $render_settings_data['import_by_order_status'] ) && ! empty( $render_settings_data['import_by_order_status'] ) ) {
					$import_by_order_status = $render_settings_data['import_by_order_status'];
					if ( $import_by_order_status != $woo_order_status ) {
						$order_status = 'Shopify Order ID : ' . $orders_data['id'] . ' Skipped Due to Order Restriction';
						return $order_status;
					}
				}

				global $wpdb;
				if ( $orders_data['id'] ) {
					$order_id = $wpdb->get_var( $wpdb->prepare( "SELECT post_id FROM $wpdb->postmeta WHERE meta_key=%s AND meta_value=%s LIMIT 1", 'ced_shopify_order_check', $orders_data['id'] ) );
					if ( $order_id ) {
						$order_status = 'Shopify Order ID : ' . $orders_data['id'] . ' Skipped! Order Already exist';
						return $order_status;
					}
				}

				$total_shipping_charge = $orders_data['total_shipping_price_set']['shop_money']['amount'];
				$total_tax_charge      = $orders_data['total_tax'];
				$order_status          = $orders_data['financial_status'];
				$order_weight          = $orders_data['total_weight'];

				if ( isset( $total_tax_charge ) && $total_tax_charge > 0 ) {
					$total_tax_charge = $total_tax_charge;
				}

				$address = array(
					'first_name' => $orders_data['customer']['default_address']['first_name'],
					'last_name'  => $orders_data['customer']['default_address']['last_name'],
					'company'    => $orders_data['customer']['default_address']['company'],
					'email'      => $orders_data['customer']['email'],
					'phone'      => $orders_data['customer']['default_address']['phone'],
					'address_1'  => $orders_data['customer']['default_address']['address1'],
					'address_2'  => $orders_data['customer']['default_address']['address2'],
					'city'       => $orders_data['customer']['default_address']['city'],
					'state'      => $orders_data['customer']['default_address']['province'],
					'postcode'   => $orders_data['customer']['default_address']['zip'],
					'country'    => $orders_data['customer']['default_address']['country'],
				);

				// Now we create the order.
				$order    = wc_create_order();
				$order_id = $order->get_id();
				if ( ! empty( $order_id ) ) {
					$order_status = 'Shopify Order ID : ' . $orders_data['id'] . ' Order Created Successfully';
				}

				// Set addresses.
				$order->set_address( $address, 'billing' );
				$order->set_address( $address, 'shipping' );

				// Line items.
				foreach ( $orders_data['line_items'] as $line_item ) {

					set_time_limit( 0 );
					wp_raise_memory_limit();

					$product = get_posts(
						array(
							'numberposts'  => -1,
							'post_type'    => array( 'product', 'product_variation' ),
							'meta_key'     => 'ced_swc_shopifyItemId',
							'meta_value'   => $line_item['product_id'],
							'meta_compare' => '=',
						)
					);

					$product     = wp_list_pluck( $product, 'ID' );
					$product_obj = wc_get_product( $product[0] );

					if ( is_object( $product_obj ) ) {
						$item_id = $order->add_product( $product_obj, $line_item['quantity'] );
					} else {
						$item_id = woocommerce_add_order_item(
							$order_id,
							array(
								'order_item_name' => $line_item['title'],
								'order_item_type' => 'line_item',
							)
						);

						if ( $item_id ) {
							$total_price = $line_item['quantity'] * $line_item['price'];
							woocommerce_add_order_item_meta( $item_id, '_qty', $line_item['quantity'] );
							woocommerce_add_order_item_meta( $item_id, '_line_total', $total_price );
							woocommerce_add_order_item_meta( $item_id, 'sku', $line_item['sku'] );
							woocommerce_add_order_item_meta( $item_id, 'weight', $line_item['grams'] . ' ( In Grams )' );
						}
					}
				}

				// Shipping Charges.
				$shipping_charges = new WC_Order_Item_Shipping();
				$shipping_charges->set_method_title( 'Shopify Order' );
				$shipping_charges->set_total( $total_shipping_charge );

				// Add item to order and save Shipping Charges.
				$order->add_item( $shipping_charges );

				// Set the array for tax calculations.
				$calculate_tax_for = array(
					'country'  => $orders_data['shipping_address']['country'],
					'postcode' => $orders_data['shipping_address']['zip'],
					'city'     => $orders_data['shipping_address']['city'],
				);

				// Get a new instance of the WC_Order_Item_Fee Object.
				$item_fee = new WC_Order_Item_Fee();
				$item_fee->set_name( 'Tax Amount' );        // Generic fee name.
				$item_fee->set_amount( $total_tax_charge ); // Fee amount.

				$item_fee->set_total( $total_tax_charge ); // Fee amount.
				// Calculating Fee taxes.
				$item_fee->calculate_taxes( $calculate_tax_for );
				// Add Fee item to the order.
				$order->add_item( $item_fee );

				// Calculate totals.
				$order->calculate_totals();

				update_post_meta( $order->get_id(), 'ced_check_isit_shopify_order', 'shopify' );

				$order->update_status( $woo_order_status );

				$render_settings_data = get_option( 'ced_shopify_settings_data', true );
				if ( isset( $render_settings_data['default_order_status'] ) && ! empty( $render_settings_data['default_order_status'] ) ) {
					$order->update_status( $render_settings_data['default_order_status'] );
				}
				update_post_meta( $order->get_id(), 'ced_shopify_order_check', $orders_data['id'] );
				update_post_meta( $order_id, 'ced_cart_weight', $order_weight );

				// Save.
				$order->save();
			}
			return $order_status;
		}


	}
}
