<?php
/**
 * Products
 *
 * @link       https://cedcommerce.com
 * @since      1.0.0
 *
 * @package    Shopify_Connector_For_Woocommerce
 * @subpackage Shopify_Connector_For_Woocommerce/includes/shopify
 */

if ( ! class_exists( 'Ced_Shopify_Product' ) ) {
	/**
	 * Ced_Shopify_Product
	 *
	 * @since      1.0.0
	 * @package    Shopify_Connector_For_Woocommerce
	 * @subpackage Shopify_Connector_For_Woocommerce/includes/shopify
	 */
	class Ced_Shopify_Product {
		/**
		 * Declare $_instance.
		 *
		 * @var string
		 */
		private static $_instance;
		/**
		 * Get_instance Instance.
		 *
		 * Ensures only one instance of Ced_Shopify_Product is loaded or can be loaded.
		 *
		 * @since 1.0.0
		 * @static
		 * @return get_instance instance.
		 */
		public static function get_instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}


		/**
		 * Ced_shopify_product ced_shopify_prepare_product_ids_to_import.
		 *
		 * @since 1.0.0
		 */
		public function ced_shopify_prepare_product_ids_to_import() {
			$collection                      = get_option( 'ced_shopify_settings_data' );
			$selected_collection             = $collection['collection_data'];
			$product_for_selected_collection = array();
			$products                        = array();

			$render_settings_data = get_option( 'ced_shopify_settings_data', false );
			if ( isset( $render_settings_data['store_address'] ) && isset( $render_settings_data['access_token'] ) ) {
				$ced_store_address = $render_settings_data['store_address'];
				$ced_access_token  = $render_settings_data['access_token'];
			}

			require_once CED_SCW_PATH . 'includes/shopify/class-ced-shopify-server-response.php';
			$ced_shopify_server_obj = Ced_Shopify_Server_Response::get_instance();
			$params                 = array();
			$params['domain']       = home_url();
			$params['shop_url']     = ! empty( $ced_store_address ) ? $ced_store_address : '';
			$params['access_token'] = ! empty( $ced_access_token ) ? $ced_access_token : '';
			$params['channel']      = 'shopify';
			if ( ! empty( $selected_collection ) ) {
				foreach ( $selected_collection as $value ) {
					if ( '' !== $value ) {
						$page_number   = 0;
						$product_limit = 250;
						do {
							$params['functionType']  = 'get_all_collection_products';
							$params['product_limit'] = $product_limit;
							$params['value']         = $value;
							$params['pageno']        = $page_number;
							$products_collection     = $ced_shopify_server_obj->get_server_response_data( $params );

							if ( ! empty( $products_collection['products'] ) ) {
								foreach ( $products_collection['products'] as $product_id ) {
									$product_for_selected_collection[ $product_id['id'] ][] = $value;
									$page_number = $product_id['id'];
								}
							} else {
								$page_number = 0;
							}
						} while ( $page_number );
					}
				}

				update_option( 'ced_shopify_selected_collection_products', $product_for_selected_collection );
				$total_product = count( $product_for_selected_collection );
				echo json_encode(
					array(
						'total_product' => $total_product,
					)
				);
			} else {
				echo json_encode(
					array(
						'total_product' => 0,
					)
				);
			}
		}

		/**
		 * Ced_shopify_prepare_product_data_to_import.
		 *
		 * @since    1.0.0
		 * @param      int $total_product Total Product.
		 * @param      int $left_product Left Product.
		 * @param      int $limit Limit.
		 * @param      int $page Page.
		 * @param      int $product_log_path Product log path.
		 */
		public function ced_shopify_prepare_product_data_to_import( $total_product, $left_product, $limit, $page, $product_log_path ) {
			require_once CED_SCW_PATH . 'includes/shopify/class-ced-shopify-server-response.php';
			$ced_shopify_server_obj = Ced_Shopify_Server_Response::get_instance();

			$product_for_selected_collection = get_option( 'ced_shopify_selected_collection_products', array() );
			$product_array_chunk             = get_option( 'ced_Shopify_Importer_Product_array', array() );
			if ( empty( $product_array_chunk ) ) {
				$product_array_chunk = array_chunk( $product_for_selected_collection, $limit, true );
			}

			$render_settings_data = get_option( 'ced_shopify_settings_data', false );
			if ( isset( $render_settings_data['store_address'] ) && isset( $render_settings_data['access_token'] ) ) {
				$ced_store_address = $render_settings_data['store_address'];
				$ced_access_token  = $render_settings_data['access_token'];
			}

			$params                 = array();
			$params['domain']       = home_url();
			$params['functionType'] = 'getSingleProductDataFromShopify';
			$params['access_token'] = ! empty( $ced_access_token ) ? $ced_access_token : '';
			$params['shop_url']     = ! empty( $ced_store_address ) ? $ced_store_address : '';
			$params['channel']      = 'shopify';
			foreach ( $product_array_chunk[0] as $selected_id => $collection_ids ) {
				$params['shopify_product_id'] = $selected_id;
				$product_data                 = $ced_shopify_server_obj->get_server_response_data( $params );
				if ( empty( $product_data ) && ! isset( $product_data['product'] ) ) {
					echo json_encode(
						array(
							'status'  => '400',
							'message' => $product_data['message'],
						)
					);
					wp_die();
				}
				$product_status[] = $this->ced_swc_manage_product_data_from_shopify( $product_data['product'], $collection_ids );
			}

			unset( $product_array_chunk[0] );
			$product_array_chunk = array_values( $product_array_chunk );
			update_option( 'ced_Shopify_Importer_Product_array', $product_array_chunk );

			$file_open = fopen( $product_log_path, 'a' );
			foreach ( $product_status as $status ) {
				fwrite( $file_open, $status . "\n" );
			}
			fclose( $file_open );
			$total_product = (int) $total_product;
			if ( '' == $left_product ) {
				$left_product = $total_product;
			}
			$left_product = $left_product - $limit;
			if ( $left_product < 0 ) {
				$left_product = 0;
			}
			$page              = ++$page;
			$processed_product = '';
			if ( '' == $processed_product ) {
				$processed_product = $limit;
			}
			$processed_product = $total_product - $left_product;
			if ( 0 === $left_product ) {
				update_option( 'ced_Shopify_Importer_Product_array', array() );
			}
			echo json_encode(
				array(
					'status'            => '200',
					'message'           => 'success',
					'total_product'     => $total_product,
					'left_product'      => $left_product,
					'processed_product' => $processed_product,
					'limit'             => (int) $limit,
					'page'              => $page,
					'product_status'    => $product_status,
				)
			);

		}
		/**
		 * Ced_swc_manage_product_data_from_shopify.
		 *
		 * @since    1.0.0
		 * @param      array $product_data Product Data.
		 * @param      array $collection_ids Collection Ids.
		 */
		public function ced_swc_manage_product_data_from_shopify( $product_data = array(), $collection_ids = array() ) {

			set_time_limit( 0 );
			wp_raise_memory_limit();

			if ( is_array( $product_data ) && ! empty( $product_data ) ) {
				$render_settings_data = get_option( 'ced_shopify_settings_data', false );
				$shopify_product_id   = isset( $product_data['id'] ) ? $product_data['id'] : '';
				$shopify_product_sku  = isset( $product_data['variants']['0']['sku'] ) ? $product_data['variants']['0']['sku'] : '';
				$store_products       = array();

				$store_products = get_posts(
					array(
						'numberposts'  => -1,
						'post_type'    => 'product',
						'post_status'  => array( 'publish', 'draft', 'pending' ),
						'meta_key'     => 'ced_swc_shopifyItemId',
						'meta_value'   => $shopify_product_id,
						'meta_compare' => '=',
					)
				);
				$store_products = wp_list_pluck( $store_products, 'ID' );
				$collections    = get_option( 'ced_swc_config_details' );

				if ( empty( $store_products ) ) {

					// Checking the Out of Stock.
					if ( ! empty( $render_settings_data['restrict_out_of_stock'] ) && 'on' == $render_settings_data['restrict_out_of_stock'] ) {
						if ( $product_data['inventory_quantity'] <= 0 ) {
							$product_status = $product_data['title'] . ' ( Shopify Product Id- ' . $product_data['id'] . ') Skipped, Restricted Out of Stock';
							return $product_status;
						}
					}

					// Checking Product with no Image.
					if ( ! empty( $render_settings_data['restrict_no_image'] ) && 'on' == $render_settings_data['restrict_no_image'] ) {
						$images_data = isset( $product_data['images'] ) ? $product_data['images'] : array();
						if ( empty( $images_data ) ) {
							$product_status = $product_data['title'] . ' ( Shopify Product Id- ' . $product_data['id'] . ') Skipped, Restricted due to Product has no Image';
							return $product_status;
						}
					}

					$import_status = isset( $render_settings_data['product_import_status'] ) && ! empty( $render_settings_data['product_import_status'] ) ? $render_settings_data['product_import_status'] : 'publish';

					$shopify_slug = isset( $render_settings_data['import_slug_shopify'] ) && ! empty( $render_settings_data['import_slug_shopify'] ) ? $product_data['handle'] : $product_data['title'];

					$product_id = wp_insert_post(
						array(
							'post_title'   => isset( $product_data['title'] ) ? $product_data['title'] : 'Imported from Shopify - ' . $shopify_product_id,
							'post_name'    => $shopify_slug,
							'post_status'  => $import_status,
							'post_type'    => 'product',
							'post_content' => isset( $product_data['body_html'] ) ? $product_data['body_html'] : '',
						)
					);

					$product_status = $product_data['title'] . ' ( Shopify Id- ' . $product_data['id'] . ') Product Created Successfully';
					if ( ! $product_id ) {
						return;
					} else {
						update_option( 'ced_swc_productPagesSince_id', $product_data['id'] );
					}

					update_post_meta( $product_id, 'ced_swc_shopifyItemId', $shopify_product_id );

					// Create Product Category.
					$category_id_array = isset( $render_settings_data['woo_category_saved'] ) && ! empty( $render_settings_data['woo_category_saved'] ) ? $render_settings_data['woo_category_saved'] : array();
					$cat_array         = array();
					if ( ! empty( $category_id_array ) ) {
						foreach ( $category_id_array as $k2 => $cat_id ) {
							$cat_array[] = intval( $cat_id );
						}
						wp_set_object_terms( $product_id, $cat_array, 'product_cat' );

					} else {
						$this->ced_swc_create_product_category( $product_id, $collection_ids );
					}

					$this->ced_swc_create_product_tags( $product_id, $product_data['tags'] );

					update_post_meta( $product_id, 'ced_swc_productData', $product_data );
					update_post_meta( $product_id, 'ced_swc_shopifyItemId', $shopify_product_id );
					update_post_meta( $product_id, 'ced_swc_shopifyVariationItemId', $product_data['variants']['0']['id'] );

					if ( isset( $product_data['options'] ) && ! empty( $product_data['options'] ) ) {
						if ( 1 == count( $product_data['options'][0]['values'] ) ) {
							if ( isset( $product_data['options'][0]['name'] ) ) {
								$this->ced_swc_import_as_simple_product( $product_id, $product_data['variants'][0], $render_settings_data );
							}
						} else {
							$variation_attributes = isset( $product_data['options'] ) ? $product_data['options'] : array();
							$variations           = isset( $product_data['variants'] ) ? $product_data['variants'] : array();

							$this->ced_swc_import_as_variable_product( $product_id, $variation_attributes, $variations, $product_data, $render_settings_data );
						}
					}

					$image_urls = isset( $product_data['images'] ) ? $product_data['images'] : array();

					if ( ! empty( $image_urls ) ) {
						foreach ( $image_urls as $key => $value ) {
							$image_url[] = substr( $value['src'], 0, strpos( $value['src'], '?' ) );
						}
					}

					// Backgroun Image Processing.
					global $process;
					$image_data = array(
						'product_id' => $product_id,
						'images_url' => $image_url,
					);

					$process->push_to_queue( $image_data );
					$process->save()->dispatch();

				} else {
					$product_status = $product_data['title'] . ' ( Shopify Product Id- ' . $shopify_product_id . ') Skipped, Already Exists';
				}
				return $product_status;
			}
		}

		/**
		 * Ced_swc_create_product_category.
		 *
		 * @since 1.0.0
		 * @param string $product_id Product Id.
		 * @param array  $collection_ids Collection Ids.
		 */
		public function ced_swc_create_product_category( $product_id = '', $collection_ids = array() ) {

			if ( empty( $product_id ) || empty( $collection_ids ) ) {
				return;
			}
			$render_settings_data = get_option( 'ced_shopify_settings_data', false );

			$collection_list = get_option( 'ced_scw_save_collections_title_list', true );
			$collection_list = $collection_list[ $render_settings_data['store_address'] ];
			if ( ! empty( $collection_list ) ) {
				foreach ( $collection_ids as $index => $ids ) {
					if ( array_key_exists( $ids, $collection_list ) ) {

						$term = wp_insert_term(
							$collection_list[ $ids ],
							'product_cat',
							array(
								'description' => $collection_list[ $ids ],
							)
						);

						if ( isset( $term->error_data['term_exists'] ) ) {
							$term_id = $term->error_data['term_exists'];
						} elseif ( isset( $term['term_id'] ) ) {
							$term_id = $term['term_id'];
						}

						if ( $term_id ) {
							$term_ids[] = $term_id;
						}
					}

					if ( ! empty( $term_ids ) ) {
						wp_set_object_terms( $product_id, $term_ids, 'product_cat' );
					}
				}
			}

		}
		/**
		 * Ced_swc_create_product_tags.
		 *
		 * @since 1.0.0
		 * @param string $product_id Product Id.
		 * @param array  $tags tags.
		 */
		public function ced_swc_create_product_tags( $product_id = '', $tags = array() ) {
			if ( isset( $tags ) ) {

				$tags = explode( ',', $tags );

				foreach ( $tags as $key => $tag_name ) {

					if ( empty( $tag_name ) ) {
						continue;
					}

					$term = wp_insert_term(
						$tag_name,                      // The term name to add.
						'product_tag'                   // The taxonomy to which to add the term.
					);

					if ( isset( $term->error_data['term_exists'] ) ) {
						$term_id[] = $term->error_data['term_exists'];
					} elseif ( isset( $term['errors'] ) ) {
						continue;
					} elseif ( isset( $term['term_id'] ) ) {
						$term_id[] = $term['term_id'];
					}
				}

				if ( isset( $term_id ) && ! empty( $term_id ) ) {
					wp_set_object_terms( $product_id, $term_id, 'product_tag' );
				}
			}
		}
		/**
		 * Ced_swc_import_as_variable_product.
		 *
		 * @since 1.0.0
		 * @param string $product_id Product Id.
		 * @param array  $variation_attributes Variation Attributes.
		 * @param string $variations Variations.
		 * @param string $product_data Product Data.
		 * @param array  $render_settings_data Render Settings Data.
		 */
		public function ced_swc_import_as_variable_product( $product_id, $variation_attributes, $variations, $product_data, $render_settings_data = array() ) {
			if ( empty( $product_id ) || empty( $variations ) || empty( $variation_attributes ) ) {
				return;
			}

			if ( ! empty( $variation_attributes ) ) {
				$this->ced_swc_create_variation_attributes( $product_id, $variation_attributes );
				$this->ced_swc_create_variations( $product_id, $variation_attributes, $variations, $product_data, $render_settings_data );
			}

		}
		/**
		 * Ced_swc_create_variations.
		 *
		 * @since 1.0.0
		 * @param string $product_id Product Id.
		 * @param array  $variation_attributes Variation Attributes.
		 * @param array  $variations Variations.
		 * @param string $product_data Product Data.
		 * @param array  $render_settings_data Render Settings Data.
		 */
		public function ced_swc_create_variations( $product_id, $variation_attributes, $variations, $product_data, $render_settings_data = array() ) {
			if ( empty( $product_id ) || empty( $variations ) || empty( $variation_attributes ) ) {
				return;
			}

			global $process;

			if ( ! empty( $variations ) ) {
				$attributes = array();
				$options    = array();
				$c          = 1;
				foreach ( $variation_attributes as $key => $attribute ) {
					$index                            = 'option' . $c;
					$attributes[ $attribute['name'] ] = $attribute['values'];
					$options[ $index ]                = $attribute['name'];
					$c++;
				}
				wp_set_object_terms( $product_id, 'variable', 'product_type' );

				$total_stock = 0;
				foreach ( $variations as $key => $variation ) {
					// Setup the post data for the variation.
					$variation_post = array(
						'post_title'  => $product_data['title'] . ' ' . $variation['title'],
						'post_name'   => 'product-' . $product_id . '-variation-' . $key,
						'post_status' => 'publish',
						'post_parent' => $product_id,
						'post_type'   => 'product_variation',
						'guid'        => home_url() . '/?product_variation=product-' . $product_id . '-variation-' . $key,
					);

					$variation_post_id = wp_insert_post( $variation_post );

					foreach ( $options as $key1 => $value ) {

						wp_set_object_terms( $variation_post_id, $variation[ $key1 ], $value );

						$attribute = strtolower( $value );
						$attribute = str_replace( ' ', '-', $attribute );
						update_post_meta( $variation_post_id, 'attribute_' . $attribute, $variation[ $key1 ] );
						$thedata = array(
							$attribute => array(
								'name'         => $variation[ $key1 ],
								'value'        => '',
								'is_visible'   => '1',
								'is_variation' => '1',
								'is_taxonomy'  => '1',
							),
						);
						update_post_meta( $variation_post_id, '_product_attributes', $thedata );
					}

					if ( ! empty( $variation['compare_at_price'] ) && $variation['compare_at_price'] > 0 ) {
						$compare_at_price = $variation['compare_at_price'];
						$price            = $variation['price'];
						if ( isset( $render_settings_data['markup_type'] ) && ! empty( $render_settings_data['markup_type'] ) ) {
							if ( isset( $render_settings_data['markup_value'] ) && ! empty( $render_settings_data['markup_value'] ) ) {
								if ( 'fixed' == $render_settings_data['markup_type'] ) {
									$compare_at_price = $compare_at_price + $render_settings_data['markup_value'];
									$price            = $price + $render_settings_data['markup_value'];
								} elseif ( 'percentage' == $render_settings_data['markup_type'] ) {
									$compare_at_price = ( $compare_at_price + ( ( $render_settings_data['markup_value'] / 100 ) * $compare_at_price ) );
									$price            = ( $price + ( ( $render_settings_data['markup_value'] / 100 ) * $price ) );
								}
							}
						}

						update_post_meta( $variation_post_id, '_regular_price', ( $compare_at_price ) );
						update_post_meta( $variation_post_id, '_price', ( $price ) );
						update_post_meta( $variation_post_id, '_sale_price', ( $price ) );
					} else {
						$price = $variation['price'];
						if ( isset( $render_settings_data['markup_type'] ) && ! empty( $render_settings_data['markup_type'] ) ) {
							if ( isset( $render_settings_data['markup_value'] ) && ! empty( $render_settings_data['markup_value'] ) ) {
								if ( 'fixed' == $render_settings_data['markup_type'] ) {
									$price = $price + $render_settings_data['markup_value'];
								} elseif ( 'percentage' == $render_settings_data['markup_type'] ) {
									$price = ( $price + ( ( $render_settings_data['markup_value'] / 100 ) * $price ) );
								}
							}
						}
						update_post_meta( $variation_post_id, '_regular_price', $variation['price'] );
						update_post_meta( $variation_post_id, '_price', $variation['price'] );
					}

					update_post_meta( $variation_post_id, '_sku', $variation['sku'] );
					update_post_meta( $variation_post_id, 'ced_swc_barcode', $variation['barcode'] );
					update_post_meta( $variation_post_id, 'ced_swc_inventory_item_id', $variation['inventory_item_id'] );

					if ( isset( $variation['inventory_quantity'] ) ) {
						if ( $variation['inventory_quantity'] > 0 ) {
							update_post_meta( $variation_post_id, '_stock', $variation['inventory_quantity'] );
							update_post_meta( $variation_post_id, '_manage_stock', 'yes' );
							update_post_meta( $variation_post_id, '_stock_status', 'instock' );
							$total_stock = $total_stock + $variation['inventory_quantity'];
						} else {
							update_post_meta( $variation_post_id, '_stock', 0 );
							update_post_meta( $variation_post_id, '_manage_stock', 'yes' );
							update_post_meta( $variation_post_id, '_stock_status', 'outofstock' );
						}
					}
					update_post_meta( $variation_post_id, '_weight', $variation['weight'] );
					update_post_meta( $variation_post_id, 'ced_swc_shopifyVariationItemId', $variation['id'] );
					update_post_meta( $variation_post_id, 'ced_swc_shopifyVariationProductData', $variation );

					/* assign variation image */
					$variation_image_id = isset( $variation['image_id'] ) ? $variation['image_id'] : '';
					if ( ! empty( $variation_image_id ) ) {
						$images = $product_data['images'];

						foreach ( $images as $index1 => $image ) {
							$main_image_array = array();
							if ( $variation_image_id == $image['id'] ) {
								$main_image_array[] = substr( $image['src'], 0, strpos( $image['src'], '?' ) );

								// Backgroun Image Processing.
								$image_data = array(
									'product_id' => $variation_post_id,
									'images_url' => $main_image_array,
								);

								$process->push_to_queue( $image_data );
							}
						}
					}

					if ( 0 == $key ) {
						$default_variation = array();
						foreach ( $options as $key1 => $value ) {
							$default_variation[ $value ] = $variation[ $key1 ];
						}
						update_post_meta( $product_id, '_default_attributes', $default_variation );
					}
				}

				update_post_meta( $product_id, '_manage_stock', 'yes' );
				update_post_meta( $product_id, '_stock', $total_stock );
				update_post_meta( $product_id, '_stock_status', 'instock' );

				$product_type = 'variable';
				$classname    = WC_Product_Factory::get_product_classname( $product_id, $product_type );
				$product      = new $classname( $product_id );
				$product->save();
			}
		}
		/**
		 * Ced_swc_create_variation_attributes.
		 *
		 * @since 1.0.0
		 * @param string $product_id Product Id.
		 * @param array  $variation_attributes Variation Attributes.
		 */
		public function ced_swc_create_variation_attributes( $product_id, $variation_attributes ) {
			if ( empty( $product_id ) || empty( $variation_attributes ) ) {
				return;
			}
			$count = 1;
			$data  = array();
			foreach ( $variation_attributes as $key => $attribute ) {
				$data['attribute_names'][]      = $attribute['name'];
				$data['attribute_position'][]   = $count;
				$data['attribute_values'][]     = implode( '|', $attribute['values'] );
				$data['attribute_visibility'][] = 1;
				$data['attribute_variation'][]  = 1;
				$count                          = ++$count;
			}

			if ( isset( $data['attribute_names'], $data['attribute_values'] ) ) {
				$attribute_names         = $data['attribute_names'];
				$attribute_values        = $data['attribute_values'];
				$attribute_visibility    = isset( $data['attribute_visibility'] ) ? $data['attribute_visibility'] : array();
				$attribute_variation     = isset( $data['attribute_variation'] ) ? $data['attribute_variation'] : array();
				$attribute_position      = $data['attribute_position'];
				$attribute_names_max_key = max( array_keys( $attribute_names ) );
				for ( $i = 0; $i <= $attribute_names_max_key; $i++ ) {
					if ( empty( $attribute_names[ $i ] ) || ! isset( $attribute_values[ $i ] ) ) {
						continue;
					}
					$attribute_id   = 0;
					$attribute_name = wc_clean( $attribute_names[ $i ] );
					if ( 'pa_' === substr( $attribute_name, 0, 3 ) ) {
						$attribute_id = wc_attribute_taxonomy_id_by_name( $attribute_name );
					}
					$options = isset( $attribute_values[ $i ] ) ? $attribute_values[ $i ] : '';
					if ( is_array( $options ) ) {
						// Term ids sent as array.
						$options = wp_parse_id_list( $options );
					} else {
						$options = wc_get_text_attributes( $options );
					}

					if ( empty( $options ) ) {
						continue;
					}
					$attribute = new WC_Product_Attribute();
					$attribute->set_id( $attribute_id );
					$attribute->set_name( $attribute_name );
					$attribute->set_options( $options );
					$attribute->set_position( $attribute_position[ $i ] );
					$attribute->set_visible( isset( $attribute_visibility[ $i ] ) );
					$attribute->set_variation( isset( $attribute_variation[ $i ] ) );
					$attributes[] = $attribute;
				}
			}
			$product_type = 'variable';
			$classname    = WC_Product_Factory::get_product_classname( $product_id, $product_type );
			$product      = new $classname( $product_id );
			$product->set_attributes( $attributes );
			$product->save();

			return;
		}
		/**
		 * Ced_swc_import_as_simple_product.
		 *
		 * @since 1.0.0
		 * @param string $product_id Product Id.
		 * @param array  $product_data Product Data.
		 * @param array  $render_settings_data Render Settings Data.
		 */
		public function ced_swc_import_as_simple_product( $product_id = '', $product_data = array(), $render_settings_data = array() ) {
			if ( empty( $product_id ) || empty( $product_data ) ) {
				return;
			}

			wp_set_object_terms( $product_id, 'simple', 'product_type' );

			if ( ! empty( $product_data['compare_at_price'] ) && $product_data['compare_at_price'] > 0 ) {

				$compare_at_price = $product_data['compare_at_price'];
				$price            = $product_data['price'];
				if ( isset( $render_settings_data['markup_type'] ) && ! empty( $render_settings_data['markup_type'] ) ) {
					if ( isset( $render_settings_data['markup_value'] ) && ! empty( $render_settings_data['markup_value'] ) ) {
						if ( 'fixed' == $render_settings_data['markup_type'] ) {
							$compare_at_price = $compare_at_price + $render_settings_data['markup_value'];
							$price            = $price + $render_settings_data['markup_value'];
						} elseif ( 'percentage' == $render_settings_data['markup_type'] ) {
							$compare_at_price = ( $compare_at_price + ( ( $render_settings_data['markup_value'] / 100 ) * $compare_at_price ) );
							$price            = ( $price + ( ( $render_settings_data['markup_value'] / 100 ) * $price ) );
						}
					}
				}

				update_post_meta( $product_id, '_regular_price', ( $compare_at_price ) );
				update_post_meta( $product_id, '_price', ( $price ) );
				update_post_meta( $product_id, '_sale_price', ( $price ) );
			} else {
				$price = $product_data['price'];
				if ( isset( $render_settings_data['markup_type'] ) && ! empty( $render_settings_data['markup_type'] ) ) {
					if ( isset( $render_settings_data['markup_value'] ) && ! empty( $render_settings_data['markup_value'] ) ) {
						if ( 'fixed' == $render_settings_data['markup_type'] ) {
							$price = $price + $render_settings_data['markup_value'];
						} elseif ( 'percentage' == $render_settings_data['markup_type'] ) {
							$price = ( $price + ( ( $render_settings_data['markup_value'] / 100 ) * $price ) );
						}
					}
				}
				update_post_meta( $product_id, '_regular_price', $product_data['price'] );
				update_post_meta( $product_id, '_price', $product_data['price'] );
			}

			update_post_meta( $product_id, '_sku', $product_data['sku'] );
			update_post_meta( $product_id, 'ced_swc_barcode', $product_data['barcode'] );
			update_post_meta( $product_id, 'ced_swc_inventory_item_id', $product_data['inventory_item_id'] );

			if ( isset( $product_data['inventory_quantity'] ) ) {
				if ( $product_data['inventory_quantity'] > 0 ) {
					update_post_meta( $product_id, '_stock', $product_data['inventory_quantity'] );
					update_post_meta( $product_id, '_manage_stock', 'yes' );
					update_post_meta( $product_id, '_stock_status', 'instock' );
				} else {
					update_post_meta( $product_id, '_stock', 0 );
					update_post_meta( $product_id, '_manage_stock', 'yes' );
					update_post_meta( $product_id, '_stock_status', 'outofstock' );
				}
			}

			update_post_meta( $product_id, '_weight', $product_data['weight'] );
		}


		/**
		 * Ced_swc_update_as_variable_product
		 *
		 * @return void
		 */
		public function ced_swc_update_as_variable_product( $productId = '', $variations = array(), $productData = array(), $render_settings_data = array(), $swc_action = '' ) {
			if ( ! empty( $variations ) ) {
				$update_price = isset( $render_settings_data['update_price'] ) ? sanitize_text_field( $render_settings_data['update_price'] ) : '';
				$update_stock = isset( $render_settings_data['update_stock'] ) ? sanitize_text_field( $render_settings_data['update_stock'] ) : '';
				$total_stock  = 0;

				foreach ( $variations as $key => $variation ) {
					$store_product = array();
					$store_product = get_posts(
						array(
							'numberposts'  => -1,
							'post_type'    => 'product_variation',
							'meta_key'     => 'ced_swc_shopifyVariationItemId',
							'meta_value'   => $variation['id'],
							'meta_compare' => 'EXISTS',
						)
					);

					$store_product     = wp_list_pluck( $store_product, 'ID' );
					$variation_post_id = $store_product[0];

					if ( ! empty( $variation_post_id ) ) {
						if ( 'swc_manual' == $swc_action || ! empty( $update_price ) && 'on' == $update_price ) {
							if ( ! empty( $variation['compare_at_price'] ) && $variation['compare_at_price'] > 0 ) {
								$compare_at_price = $variation['compare_at_price'];
								$price            = $variation['price'];
								if ( isset( $render_settings_data['markup_type'] ) && ! empty( $render_settings_data['markup_type'] ) ) {
									if ( isset( $render_settings_data['markup_value'] ) && ! empty( $render_settings_data['markup_value'] ) ) {
										if ( 'fixed' == $render_settings_data['markup_type'] ) {
											$compare_at_price = $compare_at_price + $render_settings_data['markup_value'];
											$price            = $price + $render_settings_data['markup_value'];
										} elseif ( 'percentage' == $render_settings_data['markup_type'] ) {
											$compare_at_price = ( $compare_at_price + ( ( $render_settings_data['markup_value'] / 100 ) * $compare_at_price ) );
											$price            = ( $price + ( ( $render_settings_data['markup_value'] / 100 ) * $price ) );
										}
									}
								}

								update_post_meta( $variation_post_id, '_regular_price', ( $compare_at_price ) );
								update_post_meta( $variation_post_id, '_price', ( $price ) );
								update_post_meta( $variation_post_id, '_sale_price', ( $price ) );
							} else {
								$price = $variation['price'];
								if ( isset( $render_settings_data['markup_type'] ) && ! empty( $render_settings_data['markup_type'] ) ) {
									if ( isset( $render_settings_data['markup_value'] ) && ! empty( $render_settings_data['markup_value'] ) ) {
										if ( 'fixed' == $render_settings_data['markup_type'] ) {
											$price = $price + $render_settings_data['markup_value'];
										} elseif ( 'percentage' == $render_settings_data['markup_type'] ) {
											$price = ( $price + ( ( $render_settings_data['markup_value'] / 100 ) * $price ) );
										}
									}
								}
								update_post_meta( $variation_post_id, '_regular_price', $variation['price'] );
								update_post_meta( $variation_post_id, '_price', $variation['price'] );
							}
						}

						update_post_meta( $variation_post_id, '_sku', $variation['sku'] );
						update_post_meta( $variation_post_id, 'ced_swc_barcode', $variation['barcode'] );
						update_post_meta( $variation_post_id, 'ced_swc_inventory_item_id', $variation['inventory_item_id'] );
						update_post_meta( $variation_post_id, '_weight', $variation['weight'] );
						update_post_meta( $variation_post_id, 'ced_swc_shopifyVariationItemId', $variation['id'] );
						update_post_meta( $variation_post_id, 'ced_swc_shopifyVariationProductData', $variation );

						if ( 'swc_manual' == $swc_action || ! empty( $update_stock ) && 'on' == $update_stock ) {
							if ( isset( $variation['inventory_quantity'] ) ) {
								if ( $variation['inventory_quantity'] > 0 ) {
									update_post_meta( $variation_post_id, '_stock', $variation['inventory_quantity'] );
									update_post_meta( $variation_post_id, '_manage_stock', 'yes' );
									update_post_meta( $variation_post_id, '_stock_status', 'instock' );
									$total_stock = $total_stock + $variation['inventory_quantity'];
								} else {
									delete_post_meta( $variation_post_id, '_stock' );
									update_post_meta( $variation_post_id, '_manage_stock', 'yes' );
									update_post_meta( $variation_post_id, '_stock_status', 'outofstock' );
								}
							}
						}
					}
				}

				if ( ! empty( $total_stock ) ) {
					update_post_meta( $productId, '_stock', $total_stock );
					update_post_meta( $productId, '_manage_stock', 'yes' );
					update_post_meta( $productId, '_stock_status', 'instock' );
				} else {
					delete_post_meta( $productId, '_stock' );
					update_post_meta( $productId, '_manage_stock', 'yes' );
					update_post_meta( $productId, '_stock_status', 'outofstock' );
				}
			}
		}

		/**
		 * Ced_swc_update_as_simple_product
		 *
		 * @param  mixed $product_id
		 * @param  mixed $product_data
		 * @param  mixed $render_settings_data
		 * @return void
		 */
		public function ced_swc_update_as_simple_product( $product_id = '', $product_data = array(), $render_settings_data = array(), $swc_action = '' ) {
			if ( empty( $product_id ) || empty( $product_data ) ) {
				return;
			}

			wp_set_object_terms( $product_id, 'simple', 'product_type' );

			$update_price = isset( $render_settings_data['update_price'] ) ? sanitize_text_field( $render_settings_data['update_price'] ) : '';
			$update_stock = isset( $render_settings_data['update_stock'] ) ? sanitize_text_field( $render_settings_data['update_stock'] ) : '';

			if ( 'swc_manual' == $swc_action || ! empty( $update_price ) && 'on' == $update_price ) {
				if ( ! empty( $product_data['compare_at_price'] ) && $product_data['compare_at_price'] > 0 ) {
					$compare_at_price = $product_data['compare_at_price'];
					$price            = $product_data['price'];
					if ( isset( $render_settings_data['markup_type'] ) && ! empty( $render_settings_data['markup_type'] ) ) {
						if ( isset( $render_settings_data['markup_value'] ) && ! empty( $render_settings_data['markup_value'] ) ) {
							if ( 'fixed' == $render_settings_data['markup_type'] ) {
								$compare_at_price = $compare_at_price + $render_settings_data['markup_value'];
								$price            = $price + $render_settings_data['markup_value'];
							} elseif ( 'percentage' == $render_settings_data['markup_type'] ) {
								$compare_at_price = ( $compare_at_price + ( ( $render_settings_data['markup_value'] / 100 ) * $compare_at_price ) );
								$price            = ( $price + ( ( $render_settings_data['markup_value'] / 100 ) * $price ) );
							}
						}
					}

					update_post_meta( $product_id, '_regular_price', ( $compare_at_price ) );
					update_post_meta( $product_id, '_price', ( $price ) );
					update_post_meta( $product_id, '_sale_price', ( $price ) );
				} else {
					$price = $product_data['price'];
					if ( isset( $render_settings_data['markup_type'] ) && ! empty( $render_settings_data['markup_type'] ) ) {
						if ( isset( $render_settings_data['markup_value'] ) && ! empty( $render_settings_data['markup_value'] ) ) {
							if ( 'fixed' == $render_settings_data['markup_type'] ) {
								$price = $price + $render_settings_data['markup_value'];
							} elseif ( 'percentage' == $render_settings_data['markup_type'] ) {
								$price = ( $price + ( ( $render_settings_data['markup_value'] / 100 ) * $price ) );
							}
						}
					}
					update_post_meta( $product_id, '_regular_price', $product_data['price'] );
					update_post_meta( $product_id, '_price', $product_data['price'] );
				}
			}

			if ( 'swc_manual' == $swc_action || ! empty( $update_stock ) && 'on' == $update_stock ) {
				if ( isset( $product_data['inventory_quantity'] ) ) {
					if ( $product_data['inventory_quantity'] > 0 ) {
						update_post_meta( $product_id, '_stock', $product_data['inventory_quantity'] );
						update_post_meta( $product_id, '_manage_stock', 'yes' );
						update_post_meta( $product_id, '_stock_status', 'instock' );
					} else {
						update_post_meta( $product_id, '_stock', 0 );
						update_post_meta( $product_id, '_manage_stock', 'yes' );
						update_post_meta( $product_id, '_stock_status', 'outofstock' );
					}
				}
			}

			update_post_meta( $product_id, '_sku', $product_data['sku'] );
			update_post_meta( $product_id, 'ced_swc_barcode', $product_data['barcode'] );
			update_post_meta( $product_id, 'ced_swc_inventory_item_id', $product_data['inventory_item_id'] );
			update_post_meta( $product_id, '_weight', $product_data['weight'] );
		}
	}
}
