<?php
/**
 * Server Response File
 *
 * @link       https://cedcommerce.com
 * @since      1.0.0
 *
 * @package    Shopify_Connector_For_Woocommerce
 * @subpackage Shopify_Connector_For_Woocommerce/shopify/includes
 */

if ( ! class_exists( 'Ced_Shopify_Server_Response' ) ) {
	/**
	 * Ced_Shopify_Server_Response.
	 *
	 * This class defines all code necessary to run during the plugin's activation.
	 *
	 * @since      1.0.0
	 * @package    Shopify_Connector_For_Woocommerce
	 * @subpackage Shopify_Connector_For_Woocommerce/includes
	 */
	class Ced_Shopify_Server_Response {
		/**
		 * $_instance.
		 *
		 * @since    1.0.0
		 * @var      static $_instance instance.
		 */
		private static $_instance;
		/**
		 * Get_instance Instance.
		 *
		 * Ensures only one instance of Ced_Shopify_Server_Response is loaded or can be loaded.
		 *
		 * @since 1.0.0
		 * @static
		 * @return get_instance instance.
		 */
		public static function get_instance() {
			if ( is_null( self::$_instance ) ) {
				self::$_instance = new self();
			}
			return self::$_instance;
		}
		/**
		 * Get the server response data.
		 *
		 * @since 1.0.0
		 * @param array $params  The priority at which the function should be fired.
		 */
		public function get_server_response_data( $params = array() ) {
			$url        = 'https://woodemo.cedcommerce.com/wooapi/ced-wooapi-process-request.php';
			$connection = curl_init();
			curl_setopt( $connection, CURLOPT_URL, $url );
			curl_setopt( $connection, CURLOPT_SSL_VERIFYPEER, 0 );
			curl_setopt( $connection, CURLOPT_POST, 1 );
			curl_setopt( $connection, CURLOPT_SSL_VERIFYHOST, 0 );
			curl_setopt( $connection, CURLOPT_POSTFIELDS, $params );
			curl_setopt( $connection, CURLOPT_RETURNTRANSFER, 1 );
			$response = curl_exec( $connection );
			$response = json_decode( $response, true );
			curl_close( $connection );
			if ( isset( $response['status'] ) && 400 == $response['status'] ) {
				$data                           = get_option( 'ced_saas_contract_details', array() );
				$data['shopify']['plan_status'] = 'canceled';
				update_option( 'ced_saas_contract_details', $data );
			} else {
				$data                           = get_option( 'ced_saas_contract_details', array() );
				$data['shopify']['plan_status'] = 'active';
				update_option( 'ced_saas_contract_details', $data );
			}
			return $response;
		}
	}
}

