<?php
/**
 * Setting Page
 *
 * @link       https://cedcommerce.com
 * @since      1.0.0
 *
 * @package    Shopify_Connector_For_Woocommerce
 * @subpackage Shopify_Connector_For_Woocommerce/includes
 */

if ( ! defined( 'WPINC' ) ) {
	die;
}
if ( file_exists( CED_SCW_PATH . 'admin/partials/ced-scw-header.php' ) ) {
	require_once CED_SCW_PATH . 'admin/partials/ced-scw-header.php';
}

$retrieved_list_of_locations = get_option( 'ced_scw_shopify_store_locations', array() );
$selected_location_id        = get_option( 'ced_scw_selected_location_id' );
$shopify_collection          = get_option( 'ced_scw_save_collections_title_list', array() );

?>
<div class="ced_scw_shopify_connector_loader">
	<img src="<?php echo esc_url( CED_SCW_URL . 'admin/images/loading.gif' ); ?>" width="50px" height="50px" class="ced_shopify_loading_img" >
</div>
<div class="ced-scw-setting-page">
	<section class="ced-setting-container">
		<form method="post" action="">
			<?php wp_nonce_field( 'settings_data', 'ced_settings_submit' ); ?>
			<?php
			if ( isset( $_POST['ced_save_settings'] ) ) {
				if ( ! isset( $_POST['ced_settings_submit'] ) || ! wp_verify_nonce( sanitize_text_field( wp_unslash( $_POST['ced_settings_submit'] ) ), 'settings_data' ) ) {
					return;
				}

				$sanitized_array = filter_input_array( INPUT_POST );
				$settings_data   = array();
				$settings_data   = get_option( 'ced_shopify_settings_data', array() );
				$settings_data   = isset( $sanitized_array['ced_settings_data'] ) ? ( $sanitized_array['ced_settings_data'] ) : array();

				if ( '' === $settings_data['store_address'] && '' === $settings_data['access_token'] ) {
					echo '<div class="notice notice-success settings-error"><p>' . esc_html( __( 'API Path or Access Token could not be Empty!!!', 'shopify-connector-for-woocommerce' ) ) . '</p></div>';
				} else {
					require_once CED_SCW_PATH . 'includes/shopify/class-ced-shopify-server-response.php';
					$ced_shopify_server_obj = Ced_Shopify_Server_Response::get_instance();

					$admin_access_token = $settings_data['access_token'];
					$admin_store_url    = rtrim( $settings_data['store_address'], '/' ) . '/';

					$params                    = array();
					$params['domain']          = home_url();
					$params['functionType']    = 'ced_scw_fetch_access_scope';
					$params['access_token']    = $admin_access_token;
					$params['shop_url']        = $admin_store_url;
					$params['since_id']        = '';
					$params['channel']         = 'shopify';
					$params['admin_store_url'] = $admin_store_url;
					$response                  = $ced_shopify_server_obj->get_server_response_data( $params );

					if ( ! isset( $response['access_scopes'] ) ) {
						update_option( 'ced_shopify_api_status', 'invalid' );
						echo '<div class="notice notice-success settings-error"><p>' . esc_html( __( 'Invalid Store URL or Token.', 'shopify-connector-for-woocommerce' ) ) . '</p></div>';
					} else {
						update_option( 'ced_shopify_api_status', 'valid' );
					}
				}
				update_option( 'ced_shopify_settings_data', $settings_data );
				echo '<div class="notice notice-success settings-error"><p>' . esc_html( __( 'Settings Saved Successfully', 'shopify-connector-for-woocommerce' ) ) . '</p></div>';
			}
			$render_settings_data = get_option( 'ced_shopify_settings_data', false );
			?>
			<div>
				<input id="gs" name="accordion-1" type="radio" checked>
				<label for="gs">General Settings</label>
				<article>
					<div class="ced-title">
						<div class="ced-left">
							<p>Shopify store URL</p>
						</div>
						<div class="ced-right">
							<?php
								$store_address = isset( $render_settings_data['store_address'] ) ? sanitize_text_field( $render_settings_data['store_address'] ) : '';
							?>
							<input type="text" name="ced_settings_data[store_address]"
								value="<?php echo esc_attr( $store_address ); ?>" id="shopify_store_address"
								placeholder="Enter Shopify Store Url example - storename.myshopify.com/" class="ced-content-input">
							<p>Enter the Shopify Store URL</p>
						</div>
					</div>
					<div class="ced-title">
						<div class="ced-left">
							<p>Shopify Admin API Access Token</p>
						</div>
						<div class="ced-right">
							<?php
								$access_token = isset( $render_settings_data['access_token'] ) ? sanitize_text_field( $render_settings_data['access_token'] ) : '';
							?>
							<input type="text" name="ced_settings_data[access_token]"
								value="<?php echo esc_attr( $access_token ); ?>" id="shopify_access_token"
								placeholder="Enter Shopify Admin API Access Token" class="ced-content-input">
							<p><i>Learn how to create custom apps and get Admin API Access Token </i><a href="https://help.shopify.com/en/manual/apps/custom-apps" target="_blank">Click Here</a></p>
							<div class="ced-validate">
								<button id="ced_shopify_verfiy_token" name="ced_shopify_verify_token" type="button">Validate Token</button>
							</div>
							<p id="ced_shopify_verfiy_token_status"></p>
							<br>
						</div>
					</div>
				</article>
			</div>
			<div>
				<input id="ac-2" name="accordion-1" type="radio">
				<label for="ac-2">Product Import Settings</label>
				<article>
					<div class="ced-title">
						<div class="ced-left">
							<p>Enable product import</p>
						</div>
						<div class="ced-right">
							<?php
								$enable_product_import = isset( $render_settings_data['enable_product_import'] ) ? sanitize_text_field( $render_settings_data['enable_product_import'] ) : '';
							if ( 'on' == $enable_product_import ) {
								$checked = 'checked';
								$style   = 'display: contents';
							} else {
								$checked = '';
								$style   = 'display: none';
							}
							?>
							<label class="ced-switch">
								<input type="checkbox" name="ced_settings_data[enable_product_import]" id=""
									<?php echo esc_attr( $checked ); ?>>
								<span class="ced-slider round"></span>
							</label>
						</div>
					</div>
					<div class="ced-title">
						<div class="ced-left">
							<p>Fetch collection</p>
						</div>
						<div class="ced-right">
							<div class="ced-validate">
								<button id="ced_shopify_fetch_collection" name="ced_shopify_fetch_collection"
									type="button">Fetch collection</button>
							</div>
							<p id="ced_shopify_fetch_category_message"></p>
						</div>
					</div>
					<div class="ced-title">
						<div class="ced-left">
							<p>Collections</p>
						</div>
						<?php
						$collection_data             = isset( $render_settings_data['collection_data'] ) ? $render_settings_data['collection_data'] : array();
						$collection_fetch_data_array = get_option( 'ced_scw_save_collections_title_list', true );
						$collection_data_final       = isset( $render_settings_data['store_address'] ) && isset( $collection_fetch_data_array[ $render_settings_data['store_address'] ] ) ? $collection_fetch_data_array[ $render_settings_data['store_address'] ] : array();

						?>
						<div class="ced-right">
							<select id="ced-scw-collections-values" name="ced_settings_data[collection_data][]"
								class="ced-content-input ced-scw-collections" multiple>
								<?php
								if ( ! empty( $collection_data_final ) ) {
									foreach ( $collection_data_final as $key => $value ) {
										?>
									<option value="<?php echo esc_attr( $key ); ?>" 
										<?php
										if ( is_array( $collection_data ) && ! empty( is_array( $collection_data ) ) ) {
											if ( in_array( $key, $collection_data ) ) {
												echo 'selected';
											}
										}
										?>
									><?php echo esc_attr( $value ); ?></option>
										<?php
									}
								}
								?>

							</select>
							<p>Select collections</p>
						</div>
					</div>
					<div class="ced-title">
						<div class="ced-left">
							<p>Exclude out of stock</p>
						</div>
						<div class="ced-right">
							<?php
								$restrict_out_of_stock = isset( $render_settings_data['restrict_out_of_stock'] ) ? sanitize_text_field( $render_settings_data['restrict_out_of_stock'] ) : '';
							if ( 'on' == $restrict_out_of_stock ) {
								$checked = 'checked';
								$style   = 'display: contents';
							} else {
								$checked = '';
								$style   = 'display: none';
							}
							?>

							<label class="ced-switch">
								<input type="checkbox" name="ced_settings_data[restrict_out_of_stock]"
									id="shopify_out_of_stock" <?php echo esc_attr( $checked ); ?>>
								<span class="ced-slider round"></span>
							</label>
						</div>
					</div>
					<div class="ced-title">
						<div class="ced-left">
							<p>Exclude products with no images</p>
						</div>
						<div class="ced-right">
							<?php
								$restrict_no_image = isset( $render_settings_data['restrict_no_image'] ) ? sanitize_text_field( $render_settings_data['restrict_no_image'] ) : '';
							if ( 'on' == $restrict_no_image ) {
								$checked = 'checked';
								$style   = 'display: contents';
							} else {
								$checked = '';
								$style   = 'display: none';
							}
							?>

							<label class="ced-switch">
								<input type="checkbox" name="ced_settings_data[restrict_no_image]"
									id="shopify_no_image" <?php echo esc_attr( $checked ); ?>>
								<span class="ced-slider round"></span>
							</label>
						</div>
					</div>

					<div class="ced-title">
						<div class="ced-left">
							<p>Import slugs</p>
						</div>
						<div class="ced-right">
							<?php
								$import_slug_shopify = isset( $render_settings_data['import_slug_shopify'] ) ? sanitize_text_field( $render_settings_data['import_slug_shopify'] ) : '';
							if ( 'on' == $import_slug_shopify ) {
								$checked = 'checked';
								$style   = 'display: contents';
							} else {
								$checked = '';
								$style   = 'display: none';
							}
							?>

							<label class="ced-switch">
								<input type="checkbox" name="ced_settings_data[import_slug_shopify]"
									id="shopify_import_slug" <?php echo esc_attr( $checked ); ?>>
								<span class="ced-slider round"></span>
							</label>
							<p>Switch to keep product slug same in woocommerce as in shopify store.</p>
						</div>
					</div>

					<div class="ced-title">
						<div class="ced-left">
							<p>Product import default status</p>
						</div>
						<div class="ced-right">
							<?php
								$product_import_status = isset( $render_settings_data['product_import_status'] ) ? $render_settings_data['product_import_status'] : '';
							?>
							<select id="" name="ced_settings_data[product_import_status]" class="ced-content-input">
								<option value="" <?php echo ( '' == $product_import_status ) ? 'selected' : ''; ?>>Select Default Product Import Status</option>
								<option value="publish" <?php echo ( 'publish' == $product_import_status ) ? 'selected' : ''; ?>>Publish</option>
								<option value="draft" <?php echo ( 'draft' == $product_import_status ) ? 'selected' : ''; ?>>Draft</option>
								<option value="pending" <?php echo ( 'pending' == $product_import_status ) ? 'selected' : ''; ?>>Pending</option>
							</select>
							<p>Select product import default status</p>
						</div>
					</div>            
					<div class="ced-title">
						<div class="ced-left">
							<p>Markup type</p>
						</div>
						<div class="ced-right">
							<?php
								$markup_type = isset( $render_settings_data['markup_type'] ) ? $render_settings_data['markup_type'] : '';
							?>
							<select id="" name="ced_settings_data[markup_type]" class="ced-content-input">
								<option value="" <?php echo ( '' == $markup_type ) ? 'selected' : ''; ?>>Select markup
									type</option>
								<option value="fixed" <?php echo ( 'fixed' == $markup_type ) ? 'selected' : ''; ?>>Fixed
									Price Markup</option>
								<option value="percentage"
									<?php echo ( 'percentage' == $markup_type ) ? 'selected' : ''; ?>>Percentage Markup
								</option>
							</select>
							<p>Select markup type</p>
						</div>
					</div>
					<div class="ced-title">
						<div class="ced-left">
							<p>Markup value</p>
						</div>
						<div class="ced-right">
							<?php
								$markup_value = isset( $render_settings_data['markup_value'] ) ? sanitize_text_field( $render_settings_data['markup_value'] ) : '';
							?>
							<input type="text" name="ced_settings_data[markup_value]" id="" class="ced-content-input"
								value="<?php echo esc_attr( $markup_value ); ?>">
							<p>Enter markup value</p>
						</div>
					</div>

					<div class="ced-title">
						<div class="ced-left">
							<p>WooCommerce category</p>
						</div>
						<div class="ced-right">
							<?php
								$woo_category_saved = isset( $render_settings_data['woo_category_saved'] ) ? $render_settings_data['woo_category_saved'] : array();
								$args               = array(
									'type'       => 'product',
									'taxonomy'   => 'product_cat',
									'hide_empty' => false,
								);
								$categories         = get_categories( $args );

								?>
							<select id="ced_discogs_woo_category" class="ced-content-input ced-scw-woocat" name="ced_settings_data[woo_category_saved][]" multiple>
								<?php
								foreach ( $categories as $category ) {
									?>
									<option value="<?php echo esc_attr( $category->term_id ); ?>" 
										<?php
										if ( is_array( $woo_category_saved ) && ! empty( $woo_category_saved ) ) {
											if ( in_array( $category->term_id, $woo_category_saved ) ) {
												echo 'selected';
											}
										}
										?>
									><?php echo esc_attr( $category->name ); ?></option>
									<?php
								}

								?>
							</select>    
							<p>Select WooCommerce category</p>
						</div>
					</div>

					<div class="ced-title">
						<div class="ced-left">
							<p>Chunk size</p>
						</div>
						<div class="ced-right">
							<?php
								$product_chunk_size = isset( $render_settings_data['product_chunk_size'] ) && ! empty( $render_settings_data['product_chunk_size'] ) ? sanitize_text_field( $render_settings_data['product_chunk_size'] ) : '5';
							?>
							<input type="number" min="1" max="100" name="ced_settings_data[product_chunk_size]"
								value="<?php echo esc_attr( $product_chunk_size ); ?>" placeholder=""
								class="ced-content-input">
							<p>Enter chunk size</p>
						</div>
					</div>
				</article>
			</div>
			<div>
				<input id="ac-3" name="accordion-1" type="radio">
				<label for="ac-3">Customer Import Settings</label>
				<article>
					<div class="ced-title">
						<div class="ced-left">
							<p>Enable customer import</p>
						</div>
						<div class="ced-right">
							<?php
								$enable_customer_import = isset( $render_settings_data['enable_customer_import'] ) ? sanitize_text_field( $render_settings_data['enable_customer_import'] ) : '';
							if ( 'on' == $enable_customer_import ) {
								$checked = 'checked';
								$style   = 'display: contents';
							} else {
								$checked = '';
								$style   = 'display: none';
							}
							?>

							<label class="ced-switch">
								<input type="checkbox" name="ced_settings_data[enable_customer_import]" id=""
									<?php echo esc_attr( $checked ); ?>>
								<span class="ced-slider round"></span>
							</label>
						</div>
					</div>
					<div class="ced-title">
						<div class="ced-left">
							<p>Send reset password email to client</p>
						</div>
						<div class="ced-right">
							<?php
								$send_reset_password_email = isset( $render_settings_data['send_reset_password_email'] ) ? sanitize_text_field( $render_settings_data['send_reset_password_email'] ) : '';
							if ( 'on' == $send_reset_password_email ) {
								$checked = 'checked';
								$style   = 'display: contents';
							} else {
								$checked = '';
								$style   = 'display: none';
							}
							?>
							<label class="ced-switch">
								<input type="checkbox" name="ced_settings_data[send_reset_password_email]" id=""
									<?php echo esc_attr( $checked ); ?>>
								<span class="ced-slider round"></span>
							</label>
						</div>
					</div>
					<div class="ced-title">
						<div class="ced-left">
							<p>Chunk size</p>
						</div>
						<div class="ced-right">
							<?php
								$customer_chunk_size = isset( $render_settings_data['customer_chunk_size'] ) && ! empty( $render_settings_data['customer_chunk_size'] ) ? sanitize_text_field( $render_settings_data['customer_chunk_size'] ) : '5';
							?>
							<input type="number" min="1" max="100" name="ced_settings_data[customer_chunk_size]"
								value="<?php echo esc_attr( $customer_chunk_size ); ?>" placeholder=""
								class="ced-content-input">
							<p>Enter chunk size</p>
						</div>
					</div>
				</article>
			</div>
			<div>
				<input id="ac-4" name="accordion-1" type="radio">
				<label for="ac-4">Order Import Settings</label>
				<article>
					<div class="ced-title">
						<div class="ced-left">
							<p>Enable order import</p>
						</div>
						<div class="ced-right">
							<?php
								$enable_order_import = isset( $render_settings_data['enable_order_import'] ) ? sanitize_text_field( $render_settings_data['enable_order_import'] ) : '';
							if ( 'on' == $enable_order_import ) {
								$checked = 'checked';
								$style   = 'display: contents';
							} else {
								$checked = '';
								$style   = 'display: none';
							}
							?>

							<label class="ced-switch">
								<input type="checkbox" name="ced_settings_data[enable_order_import]" id=""
									<?php echo esc_attr( $checked ); ?>>
								<span class="ced-slider round"></span>
							</label>
						</div>
					</div>
					<div class="ced-title">
						<div class="ced-left">
							<p>Set default order status</p>
						</div>
						<div class="ced-right">
							<?php
								$default_order_status = isset( $render_settings_data['default_order_status'] ) ? $render_settings_data['default_order_status'] : '';
							?>
							<select id="" name="ced_settings_data[default_order_status]" class="ced-content-input">
								<option value="" <?php echo ( '' == $default_order_status ) ? 'selected' : ''; ?>>Select
									default order status</option>
								<option value="pending"
									<?php echo ( 'pending' == $default_order_status ) ? 'selected' : ''; ?>>Pending
									Payment</option>
								<option value="failed"
									<?php echo ( 'failed' == $default_order_status ) ? 'selected' : ''; ?>>Failed
								</option>
								<option value="processing"
									<?php echo ( 'processing' == $default_order_status ) ? 'selected' : ''; ?>>
									Processing</option>
								<option value="completed"
									<?php echo ( 'completed' == $default_order_status ) ? 'selected' : ''; ?>>Completed
								</option>
								<option value="on-hold"
									<?php echo ( 'on-hold' == $default_order_status ) ? 'selected' : ''; ?>>On Hold
								</option>
								<option value="cancelled"
									<?php echo ( 'cancelled' == $default_order_status ) ? 'selected' : ''; ?>>Cancelled
								</option>
								<option value="refunded"
									<?php echo ( 'refunded' == $default_order_status ) ? 'selected' : ''; ?>>Refunded
								</option>
							</select>
						</div>
					</div>
					<div class="ced-title">
						<div class="ced-left">
							<p>Import by order status</p>
						</div>
						<div class="ced-right">
							<?php
								$import_by_order_status = isset( $render_settings_data['import_by_order_status'] ) ? $render_settings_data['import_by_order_status'] : '';
							?>
							<select id="" name="ced_settings_data[import_by_order_status]" class="ced-content-input">
								<option value="" <?php echo ( '' == $import_by_order_status ) ? 'selected' : ''; ?>>
									Select import by status</option>
								<option value="pending"
									<?php echo ( 'pending' == $import_by_order_status ) ? 'selected' : ''; ?>>Pending
									Payment</option>
								<option value="failed"
									<?php echo ( 'failed' == $import_by_order_status ) ? 'selected' : ''; ?>>Failed
								</option>
								<option value="processing"
									<?php echo ( 'processing' == $import_by_order_status ) ? 'selected' : ''; ?>>
									Processing</option>
								<option value="completed"
									<?php echo ( 'completed' == $import_by_order_status ) ? 'selected' : ''; ?>>
									Completed</option>
								<option value="on-hold"
									<?php echo ( 'on-hold' == $import_by_order_status ) ? 'selected' : ''; ?>>On Hold
								</option>
								<option value="cancelled"
									<?php echo ( 'cancelled' == $import_by_order_status ) ? 'selected' : ''; ?>>
									Cancelled</option>
								<option value="refunded"
									<?php echo ( 'refunded' == $import_by_order_status ) ? 'selected' : ''; ?>>Refunded
								</option>
							</select>
						</div>
					</div>
				   
					<div class="ced-title">
						<div class="ced-left">
							<p>Chunk Size</p>
						</div>
						<div class="ced-right">
							<?php
								$order_chunk_size = isset( $render_settings_data['order_chunk_size'] ) && ! empty( $render_settings_data['order_chunk_size'] ) ? sanitize_text_field( $render_settings_data['order_chunk_size'] ) : '5';
							?>
							<input type="number" min="1" max="100" name="ced_settings_data[order_chunk_size]"
								value="<?php echo esc_attr( $order_chunk_size ); ?>" placeholder=""
								class="ced-content-input">
							<p>Enter chunk size</p>
						</div>
					</div>
				</article>
			</div>

			<!-- Order export -->
			<div>
				<input id="ac-5" name="accordion-1" type="radio">
				<label for="ac-5">Order Export Settings</label>
				<article>

					<div class="ced-title">
						<div class="ced-left">
							<p>Select location
								</br><span class='cedcommerce-tip'>[ A location represents a geographical location where your stores, pop-up stores, headquarters, and warehouses exist. You can use the Location resource to manage inventory. ]</span>
							</p>
						</div>
						<div class="ced-right">
							<?php
							if ( empty( $retrieved_list_of_locations ) ) {
								?>
									<div class="ced-right">
										<div class="ced-validate">
											<button id="ced_shopify_get_location_list" name="ced_shopify_get_location_list" type="button">Fetch Location</button>
										</div>
										<p id="ced_shopify_fetch_category_message"></p>
									</div>
								<?php
							} else {
								?>
									<select id="ced_scw_select_location" class="ced-content-input ced-scw-location">
									<option></option>
									<?php
									foreach ( $retrieved_list_of_locations as $key => $location ) :
										?>
											<option value="<?php echo esc_attr( $location['id'] ); ?>"
												<?php
												if ( isset( $selected_location_id ) ) {
													if ( $location['id'] == $selected_location_id ) {
														echo 'selected';
													}
												}
												?>
											>
											<?php echo esc_attr( $location['name'] ); ?> </option>
										<?php endforeach ?>
									</select>
									<p>Select location</p>
								<?php
							}
							?>
						</div>
					</div>

					<div class="ced-title">
						<div class="ced-left">
							<p>Enable order export</p>
						</div>
						<div class="ced-right">
							<?php
								$enable_order_export = isset( $render_settings_data['enable_order_export'] ) ? sanitize_text_field( $render_settings_data['enable_order_export'] ) : '';
							if ( 'on' == $enable_order_export ) {
								$checked = 'checked';
								$style   = 'display: contents';
							} else {
								$checked = '';
								$style   = 'display: none';
							}
							?>
							<label class="ced-switch">
								<input type="checkbox" name="ced_settings_data[enable_order_export]" id=""
									<?php echo esc_attr( $checked ); ?>>
								<span class="ced-slider round"></span>
							</label>
						</div>
					</div>
				</article>
			</div>

			<!-- Sync setting -->
			<div>
				<input id="ac-6" name="accordion-1" type="radio">
				<label for="ac-6">Product Sync Settings</label>
				<article>
					<div class="ced-title">
						<div class="ced-left">
							<p>Schedulers
								</br><span class='cedcommerce-tip'>[ Enable to update meta. ]</span>
							</p>
						</div>
					</div>

					<div class="ced-title">
						<div class="ced-left">
							<p>Enable product title and description sync</p>
						</div>
						<div class="ced-right">
							<?php
								$enable_scheduler_description = isset( $render_settings_data['update_description'] ) ? sanitize_text_field( $render_settings_data['update_description'] ) : '';
							if ( 'on' == $enable_scheduler_description ) {
								$checked = 'checked';
								$style   = 'display: contents';
							} else {
								$checked = '';
								$style   = 'display: none';
							}
							?>
							<label class="ced-switch">
								<input type="checkbox" name="ced_settings_data[update_description]" id=""
									<?php echo esc_attr( $checked ); ?>>
								<span class="ced-slider round"></span>
							</label>
						</div>
					</div>

					<div class="ced-title">
						<div class="ced-left">
							<p>Enable stock sync</p>
						</div>
						<div class="ced-right">
							<?php
								$enable_scheduler_stock = isset( $render_settings_data['update_stock'] ) ? sanitize_text_field( $render_settings_data['update_stock'] ) : '';
							if ( 'on' == $enable_scheduler_stock ) {
								$checked = 'checked';
								$style   = 'display: contents';
							} else {
								$checked = '';
								$style   = 'display: none';
							}
							?>
							<label class="ced-switch">
								<input type="checkbox" name="ced_settings_data[update_stock]" id=""
									<?php echo esc_attr( $checked ); ?>>
								<span class="ced-slider round"></span>
							</label>
						</div>
					</div>

					<div class="ced-title">
						<div class="ced-left">
							<p>Enable price sync</p>
						</div>
						<div class="ced-right">
							<?php
								$enable_scheduler_price = isset( $render_settings_data['update_price'] ) ? sanitize_text_field( $render_settings_data['update_price'] ) : '';
							if ( 'on' == $enable_scheduler_price ) {
								$checked = 'checked';
								$style   = 'display: contents';
							} else {
								$checked = '';
								$style   = 'display: none';
							}
							?>
							<label class="ced-switch">
								<input type="checkbox" name="ced_settings_data[update_price]" id=""
									<?php echo esc_attr( $checked ); ?>>
								<span class="ced-slider round"></span>
							</label>
						</div>
					</div>
				</article>
			</div>

			<?php
			if ( isset( $_SERVER['HTTPS'] ) && 'on' === $_SERVER['HTTPS'] ) {
				$url = 'https://';
			} else {
				$url = 'http://';
			}
				$url    .= isset( $_SERVER['HTTP_HOST'] ) ? sanitize_text_field( wp_unslash( $_SERVER['HTTP_HOST'] ) ) : '';
				$url    .= isset( $_SERVER['REQUEST_URI'] ) ? sanitize_text_field( wp_unslash( $_SERVER['REQUEST_URI'] ) ) : '';
				$new_url = str_replace( 'setting-page', 'progress-page', $url );
			?>
			<input type="hidden" class="ced_shopify_current_url_setting" value="<?php echo esc_attr( $new_url ); ?>">
			<div class="ced-submit-combo">
				
				<?php
					$api_status = get_option( 'ced_shopify_api_status', true );
					$disable    = 'disabled';
					$msg        = 'Please enable one import setting to goto the next step.';

				if ( ( 'valid' == $api_status ) ) {
					if ( ( 'on' == $enable_product_import ) ) {
						if ( ! empty( $collection_data ) ) {
							$disable = '';
							$msg     = '';
						} else {

							$disable = 'disabled';
							$msg     = 'Please fetch/select collection for products import';
						}
					} elseif ( 'on' == $enable_customer_import || 'on' == $enable_order_import ) {
						$disable = '';
						$msg     = '';
					}
				}
					echo '<span style="
	position: absolute;
	left: 10%;
	color: red;
	font-weight: 400;
	font-size: 14px;
	font-style: italic;
">' . esc_attr( $msg ) . '</span>';
					echo '<button name="ced_save_settings" class="ced-btn-save">SAVE</button>';
					echo '<button type="button" class = "ced-btn-save" id = "ced_shopify_next_btn_progress"   ' . esc_attr( $disable ) . '>Next</button>';
				?>

			</div>
		</form>
	</section>
</div>
