<?php
/**
 * The plugin bootstrap file
 *
 * This file is read by WordPress to generate the plugin information in the plugin
 * admin area. This file also includes all of the dependencies used by the plugin,
 * registers the activation and deactivation functions, and defines a function
 * that starts the plugin.
 *
 * @link              https://cedcommerce.com
 * @since             1.0.0
 * @package           Shopify_Connector_For_Woocommerce
 *
 * @wordpress-plugin
 * Plugin Name:       Shopify Connector for WooCommerce
 * Plugin URI:        https://woocommerce.com/products/shopify-connector-for-woocommerce
 * Description:       The plugin allows merchants to connect their Shopify store with the WooCommerce Store.
 * Version:           1.0.5
 * Author:            CedCommerce
 * Author URI:        https://woocommerce.com/vendor/cedcommerce
 * License:           GPL-2.0+
 * License URI:       http://www.gnu.org/licenses/gpl-2.0.txt
 * Text Domain:       shopify-connector-for-woocommerce
 * Domain Path:       /languages
 * Woo: 18734001417081:0de1c3fc31c28dc8addb164031f58bcf
 */

// If this file is called directly, abort.
if ( ! defined( 'WPINC' ) ) {
	die;
}

/**
 * Currently plugin version.
 * Start at version 1.0.0 and use SemVer - https://semver.org
 * Rename this for your plugin and update it as you release new versions.
 */
define( 'SHOPIFY_CONNECTOR_FOR_WOOCOMMERCE_VERSION', '1.0.5' );
define( 'CED_SCW_PLUGIN_BASENAME', plugin_basename( __FILE__ ) );

/**
 * The code that runs during plugin activation.
 * This action is documented in includes/class-shopify-connector-for-woocommerce-activator.php
 */
function activate_shopify_connector_for_woocommerce() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-shopify-connector-for-woocommerce-activator.php';
	Shopify_Connector_For_Woocommerce_Activator::activate();
}

/**
 * The code that runs during plugin deactivation.
 * This action is documented in includes/class-shopify-connector-for-woocommerce-deactivator.php
 */
function deactivate_shopify_connector_for_woocommerce() {
	require_once plugin_dir_path( __FILE__ ) . 'includes/class-shopify-connector-for-woocommerce-deactivator.php';
	Shopify_Connector_For_Woocommerce_Deactivator::deactivate();
}

register_activation_hook( __FILE__, 'activate_shopify_connector_for_woocommerce' );
register_deactivation_hook( __FILE__, 'deactivate_shopify_connector_for_woocommerce' );

/**
 * The core plugin class that is used to define internationalization,
 * admin-specific hooks, and public-facing site hooks.
 */
require plugin_dir_path( __FILE__ ) . 'includes/class-shopify-connector-for-woocommerce.php';

/**
 * Begins execution of the plugin.
 *
 * Since everything within the plugin is registered via hooks,
 * then kicking off the plugin from this point in the file does
 * not affect the page life cycle.
 *
 * @since    1.0.0
 */
function run_shopify_connector_for_woocommerce() {
	$plugin = new Shopify_Connector_For_Woocommerce();
	$plugin->run();
}
/**
 * Begins execution of the plugin.
 *
 * Ced_swc_shopify_check_woocommerce_active
 *
 * @since    1.0.0
 */
function ced_swc_shopify_check_woocommerce_active() {
	if ( in_array( 'woocommerce/woocommerce.php', apply_filters( 'active_plugins', get_option( 'active_plugins' ) ) ) ) {
		return true;
	}
	return false;
}

/**
 * Ced_shopify_admin_notice_activation
 *
 * @since    1.0.0
 */
function ced_shopify_admin_notice_activation() {
	if ( get_transient( 'ced-swc-admin-notice' ) ) {?>
		<div class="updated notice is-dismissible">
			<p>Welcome to Shopify Connector For WooCommerce.</p>
			<a href="admin.php?page=ced_plans&product_plan=shopify" class ="ced_configuration_plugin_main">Connect to Shopify</a>
		</div>
		<?php
		delete_transient( 'ced-swc-admin-notice' );
	}
}

/**
 * Ced_admin_notice_example_activation_hook_ced_shopify
 *
 * @since    1.0.0
 */
function ced_admin_notice_example_activation_hook_ced_shopify() {
	set_transient( 'ced-swc-admin-notice', true, 5 );
}

/**
 * Ced_shopify_woo_missing_notice
 *
 * @since    1.0.0
 */
function ced_shopify_woo_missing_notice() {
	// translators: %s: search term !!
	echo '<div class="notice notice-error is-dismissible"><p>' . sprintf( esc_html( __( 'Shopify Connector For Woocommerce requires WooCommerce to be installed and active. You can download %s from here.', 'shopify-connector-for-woocommerce' ) ), '<a href="https://wordpress.org/plugins/woocommerce/" target="_blank">WooCommerce</a>' ) . '</p></div>';
}
/**
 * Deactivate_ced_shopify_woo
 *
 * @since    1.0.0
 */
function deactivate_ced_shopify_woo() {
	deactivate_plugins( CED_SCW_PLUGIN_BASENAME );
	add_action( 'admin_notices', 'ced_shopify_woo_missing_notice' );
	if ( isset( $_GET['activate'] ) ) {
		unset( $_GET['activate'] );
	}
}

if ( ced_swc_shopify_check_woocommerce_active() ) {
	run_shopify_connector_for_woocommerce();
	register_activation_hook( __FILE__, 'ced_admin_notice_example_activation_hook_ced_shopify' );
	add_action( 'admin_notices', 'ced_shopify_admin_notice_activation' );
} else {
	add_action( 'admin_init', 'deactivate_ced_shopify_woo' );
}
